@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2020 Intel Corporation. All rights reserved.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -79,6 +79,20 @@ def mba_supported():
     return common.MBA_CAP in SYSTEM_CAPS
 
 
+def mba_bw_supported():
+    """
+    Returns MBA BW support status
+    """
+    return common.PQOS_API.is_mba_bw_supported()
+
+
+def mba_bw_enabled():
+    """
+    Returns MBA BW enabled status
+    """
+    return common.PQOS_API.is_mba_bw_enabled()
+
+
 def sstbf_enabled():
     """
     Returns SST-BF support status
