@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,7 @@
  */
 
 #include <string.h>
+#include <stdlib.h>
 
 #include "pqos.h"
 #include "api.h"
@@ -41,10 +42,11 @@
 #include "os_monitoring.h"
 #include "monitoring.h"
 #include "os_monitoring.h"
+#include "hw_monitoring.h"
 #include "cap.h"
 #include "log.h"
 #include "types.h"
-#include "cpu_registers.h"
+#include "cpuinfo.h"
 
 /**
  * Value marking monitoring group structure as "valid".
@@ -60,20 +62,87 @@
  */
 static int m_interface = PQOS_INTER_MSR;
 
+/**
+ * PQoS API functions
+ */
+static struct pqos_api {
+        /** Starts resource monitoring on selected group of cores */
+        int (*mon_start)(const unsigned num_cores,
+                         const unsigned *cores,
+                         const enum pqos_mon_event event,
+                         void *context,
+                         struct pqos_mon_data *group);
+        /** Starts resource monitoring of selected pids */
+        int (*mon_start_pids)(const unsigned num_pids,
+                              const pid_t *pids,
+                              const enum pqos_mon_event event,
+                              void *context,
+                              struct pqos_mon_data *group);
+        /*Stops resource monitoring data for selected monitoring group */
+        int (*mon_stop)(struct pqos_mon_data *group);
+
+        /** Set MBA */
+        int (*mba_get)(const unsigned mba_id,
+                       const unsigned max_num_cos,
+                       unsigned *num_cos,
+                       struct pqos_mba *mba_tab);
+        /** Get MBA mask */
+        int (*mba_set)(const unsigned mba_id,
+                       const unsigned num_cos,
+                       const struct pqos_mba *requested,
+                       struct pqos_mba *actual);
+        /** Assign first available COS */
+        int (*alloc_assign)(const unsigned technology,
+                            const unsigned *core_array,
+                            const unsigned core_num,
+                            unsigned *class_id);
+} api;
+
 /*
  * =======================================
  * Init module
  * =======================================
  */
 int
-api_init(int interface)
+api_init(int interface, enum pqos_vendor vendor)
 {
         if (interface != PQOS_INTER_MSR && interface != PQOS_INTER_OS &&
-                interface != PQOS_INTER_OS_RESCTRL_MON)
+            interface != PQOS_INTER_OS_RESCTRL_MON)
                 return PQOS_RETVAL_PARAM;
 
         m_interface = interface;
 
+        memset(&api, 0, sizeof(api));
+
+        if (interface == PQOS_INTER_MSR) {
+                api.mon_start = hw_mon_start;
+                api.mon_stop = hw_mon_stop;
+                if (vendor == PQOS_VENDOR_AMD) {
+                        api.mba_get = hw_mba_get_amd;
+                        api.mba_set = hw_mba_set_amd;
+                } else {
+                        api.mba_get = hw_mba_get;
+                        api.mba_set = hw_mba_set;
+                }
+                api.alloc_assign = hw_alloc_assign;
+
+#ifdef __linux__
+        } else if (interface == PQOS_INTER_OS ||
+                   interface == PQOS_INTER_OS_RESCTRL_MON) {
+                api.mon_start = os_mon_start;
+                api.mon_start_pids = os_mon_start_pids;
+                api.mon_stop = os_mon_stop;
+                if (vendor == PQOS_VENDOR_AMD) {
+                        api.mba_get = os_mba_get_amd;
+                        api.mba_set = os_mba_set_amd;
+                } else {
+                        api.mba_get = os_mba_get;
+                        api.mba_set = os_mba_set;
+                }
+                api.alloc_assign = os_alloc_assign;
+#endif
+        }
+
         return PQOS_RETVAL_OK;
 }
 
@@ -83,8 +152,7 @@ api_init(int interface)
  * =======================================
  */
 int
-pqos_alloc_assoc_set(const unsigned lcore,
-                     const unsigned class_id)
+pqos_alloc_assoc_set(const unsigned lcore, const unsigned class_id)
 {
         int ret;
 
@@ -112,8 +180,7 @@ pqos_alloc_assoc_set(const unsigned lcore,
 }
 
 int
-pqos_alloc_assoc_get(const unsigned lcore,
-                     unsigned *class_id)
+pqos_alloc_assoc_get(const unsigned lcore, unsigned *class_id)
 {
         int ret;
 
@@ -144,8 +211,7 @@ pqos_alloc_assoc_get(const unsigned lcore,
 }
 
 int
-pqos_alloc_assoc_set_pid(const pid_t task,
-                         const unsigned class_id)
+pqos_alloc_assoc_set_pid(const pid_t task, const unsigned class_id)
 {
         int ret;
 
@@ -158,7 +224,7 @@ pqos_alloc_assoc_set_pid(const pid_t task,
         }
 
         if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -176,12 +242,10 @@ pqos_alloc_assoc_set_pid(const pid_t task,
         _pqos_api_unlock();
 
         return ret;
-
 }
 
 int
-pqos_alloc_assoc_get_pid(const pid_t task,
-                         unsigned *class_id)
+pqos_alloc_assoc_get_pid(const pid_t task, unsigned *class_id)
 {
         int ret;
 
@@ -197,7 +261,7 @@ pqos_alloc_assoc_get_pid(const pid_t task,
         }
 
         if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -239,17 +303,13 @@ pqos_alloc_assign(const unsigned technology,
                 _pqos_api_unlock();
                 return ret;
         }
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_alloc_assign(technology, core_array,
-                        core_num, class_id);
+
+        if (api.alloc_assign != NULL)
+                ret = api.alloc_assign(technology, core_array, core_num,
+                                       class_id);
         else {
-#ifdef __linux__
-                ret = os_alloc_assign(technology, core_array, core_num,
-                                      class_id);
-#else
-                LOG_INFO("OS interface not supported!\n");
+                LOG_INFO("Interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
-#endif
         }
         _pqos_api_unlock();
 
@@ -257,8 +317,7 @@ pqos_alloc_assign(const unsigned technology,
 }
 
 int
-pqos_alloc_release(const unsigned *core_array,
-                   const unsigned core_num)
+pqos_alloc_release(const unsigned *core_array, const unsigned core_num)
 {
         int ret;
 
@@ -308,7 +367,7 @@ pqos_alloc_assign_pid(const unsigned technology,
         }
 
         if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -328,8 +387,7 @@ pqos_alloc_assign_pid(const unsigned technology,
 }
 
 int
-pqos_alloc_release_pid(const pid_t *task_array,
-                       const unsigned task_num)
+pqos_alloc_release_pid(const pid_t *task_array, const unsigned task_num)
 {
         int ret;
 
@@ -345,7 +403,7 @@ pqos_alloc_release_pid(const pid_t *task_array,
         }
 
         if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -386,8 +444,7 @@ pqos_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
                 return PQOS_RETVAL_PARAM;
         }
 
-        if (mba_cfg != PQOS_MBA_ANY &&
-            mba_cfg != PQOS_MBA_DEFAULT &&
+        if (mba_cfg != PQOS_MBA_ANY && mba_cfg != PQOS_MBA_DEFAULT &&
             mba_cfg != PQOS_MBA_CTRL) {
                 LOG_ERROR("Unrecognized MBA configuration setting %d!\n",
                           mba_cfg);
@@ -426,12 +483,6 @@ pqos_pid_get_pid_assoc(const unsigned class_id, unsigned *count)
         if (count == NULL)
                 return NULL;
 
-        if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
-                LOG_ERROR("Incompatible interface "
-                          "selected for task association!\n");
-                return NULL;
-        }
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -440,6 +491,14 @@ pqos_pid_get_pid_assoc(const unsigned class_id, unsigned *count)
                 return NULL;
         }
 
+        if (m_interface != PQOS_INTER_OS &&
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task association!\n");
+                _pqos_api_unlock();
+                return NULL;
+        }
+
 #ifdef __linux__
         tasks = os_pid_get_pid_assoc(class_id, count);
         if (tasks == NULL)
@@ -486,7 +545,7 @@ is_contiguous(uint64_t bitmask)
         while ((bitmask & 1) != 0) /**< Shift until 0 found at position 0 */
                 bitmask >>= 1;
 
-        return (bitmask) ? 0 : 1;  /**< non-zero bitmask is not contiguous */
+        return (bitmask) ? 0 : 1; /**< non-zero bitmask is not contiguous */
 }
 
 int
@@ -500,14 +559,6 @@ pqos_l3ca_set(const unsigned l3cat_id,
         if (ca == NULL || num_cos == 0)
                 return PQOS_RETVAL_PARAM;
 
-        _pqos_api_lock();
-
-        ret = _pqos_check_init(1);
-        if (ret != PQOS_RETVAL_OK) {
-                _pqos_api_unlock();
-                return ret;
-        }
-
         /**
          * Check if class bitmasks are contiguous.
          */
@@ -516,18 +567,25 @@ pqos_l3ca_set(const unsigned l3cat_id,
 
                 if (ca[i].cdp) {
                         is_contig = is_contiguous(ca[i].u.s.data_mask) &&
-                                is_contiguous(ca[i].u.s.code_mask);
+                                    is_contiguous(ca[i].u.s.code_mask);
                 } else
                         is_contig = is_contiguous(ca[i].u.ways_mask);
 
                 if (!is_contig) {
                         LOG_ERROR("L3 COS%u bit mask is not contiguous!\n",
                                   ca[i].class_id);
-                        _pqos_api_unlock();
                         return PQOS_RETVAL_PARAM;
                 }
         }
 
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
         if (m_interface == PQOS_INTER_MSR)
                 ret = hw_l3ca_set(l3cat_id, num_cos, ca);
         else {
@@ -625,14 +683,6 @@ pqos_l2ca_set(const unsigned l2id,
         if (ca == NULL || num_cos == 0)
                 return PQOS_RETVAL_PARAM;
 
-        _pqos_api_lock();
-
-        ret = _pqos_check_init(1);
-        if (ret != PQOS_RETVAL_OK) {
-                _pqos_api_unlock();
-                return ret;
-        }
-
         /**
          * Check if class bitmasks are contiguous
          */
@@ -641,17 +691,25 @@ pqos_l2ca_set(const unsigned l2id,
 
                 if (ca[i].cdp) {
                         is_contig = is_contiguous(ca[i].u.s.data_mask) &&
-                                is_contiguous(ca[i].u.s.code_mask);
+                                    is_contiguous(ca[i].u.s.code_mask);
                 } else
                         is_contig = is_contiguous(ca[i].u.ways_mask);
 
                 if (!is_contig) {
                         LOG_ERROR("L2 COS%u bit mask is not contiguous!\n",
                                   ca[i].class_id);
-                        _pqos_api_unlock();
                         return PQOS_RETVAL_PARAM;
                 }
         }
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
         if (m_interface == PQOS_INTER_MSR)
                 ret = hw_l2ca_set(l2id, num_cos, ca);
         else {
@@ -751,18 +809,6 @@ pqos_mba_set(const unsigned mba_id,
         if (requested == NULL || num_cos == 0)
                 return PQOS_RETVAL_PARAM;
 
-        /**
-         * Check if MBA rate is within allowed range
-         */
-        for (i = 0; i < num_cos; i++)
-                if (requested[i].ctrl == 0 &&
-                    (requested[i].mb_max == 0 ||
-                     requested[i].mb_max > PQOS_MBA_LINEAR_MAX)) {
-                        LOG_ERROR("MBA COS%u rate out of range (from 1-%d)!\n",
-                                   requested[i].class_id, PQOS_MBA_LINEAR_MAX);
-                        return PQOS_RETVAL_PARAM;
-                }
-
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -771,21 +817,33 @@ pqos_mba_set(const unsigned mba_id,
                 return ret;
         }
 
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mba_set(mba_id, num_cos, requested, actual);
+        /**
+         * Check if MBA rate is within allowed range
+         */
+        for (i = 0; i < num_cos; i++) {
+                const struct cpuinfo_config *vconfig;
+
+                cpuinfo_get_config(&vconfig);
+                if (requested[i].ctrl == 0 &&
+                    (requested[i].mb_max == 0 ||
+                     requested[i].mb_max > vconfig->mba_max)) {
+                        LOG_ERROR("MBA COS%u rate out of range (from 1-%d)!\n",
+                                  requested[i].class_id, vconfig->mba_max);
+                        _pqos_api_unlock();
+                        return PQOS_RETVAL_PARAM;
+                }
+        }
+
+        if (api.mba_set != NULL)
+                ret = api.mba_set(mba_id, num_cos, requested, actual);
         else {
-#ifdef __linux__
-                ret = os_mba_set(mba_id, num_cos, requested, actual);
-#else
-                LOG_INFO("OS interface not supported!\n");
+                LOG_INFO("Interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
-#endif
         }
 
         _pqos_api_unlock();
 
         return ret;
-
 }
 
 int
@@ -807,15 +865,11 @@ pqos_mba_get(const unsigned mba_id,
                 return ret;
         }
 
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mba_get(mba_id, max_num_cos, num_cos, mba_tab);
+        if (api.mba_get != NULL)
+                ret = api.mba_get(mba_id, max_num_cos, num_cos, mba_tab);
         else {
-#ifdef __linux__
-                ret = os_mba_get(mba_id, max_num_cos, num_cos, mba_tab);
-#else
-                LOG_INFO("OS interface not supported!\n");
+                LOG_INFO("Interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
-#endif
         }
 
         _pqos_api_unlock();
@@ -859,11 +913,13 @@ pqos_mon_reset(void)
 }
 
 int
-pqos_mon_assoc_get(const unsigned lcore,
-                   pqos_rmid_t *rmid)
+pqos_mon_assoc_get(const unsigned lcore, pqos_rmid_t *rmid)
 {
         int ret;
 
+        if (rmid == NULL)
+                return PQOS_RETVAL_PARAM;
+
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -922,18 +978,27 @@ pqos_mon_start(const unsigned num_cores,
                 return ret;
         }
 
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mon_start(num_cores, cores, event, context, group);
-        else {
-#ifdef __linux__
-                ret = os_mon_start(num_cores, cores, event, context, group);
-#else
-                LOG_INFO("OS interface not supported!\n");
+        memset(group, 0, sizeof(*group));
+        group->intl =
+            (struct pqos_mon_data_internal *)malloc(sizeof(*group->intl));
+        if (group->intl == NULL) {
                 ret = PQOS_RETVAL_RESOURCE;
-#endif
+                goto pqos_mon_start_exit;
         }
+        memset(group->intl, 0, sizeof(*group->intl));
+
+        if (api.mon_start != NULL)
+                ret = api.mon_start(num_cores, cores, event, context, group);
+        else {
+                LOG_INFO("Interface not supported!\n");
+                ret = PQOS_RETVAL_RESOURCE;
+        }
+
+pqos_mon_start_exit:
         if (ret == PQOS_RETVAL_OK)
                 group->valid = GROUP_VALID_MARKER;
+        else if (group->intl != NULL)
+                free(group->intl);
 
         _pqos_api_unlock();
 
@@ -959,24 +1024,24 @@ pqos_mon_stop(struct pqos_mon_data *group)
                 return ret;
         }
 
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mon_stop(group);
+        if (api.mon_stop != NULL)
+                ret = api.mon_stop(group);
         else {
-#ifdef __linux__
-                ret = os_mon_stop(group);
-#else
-                LOG_INFO("OS interface not supported!\n");
+                LOG_INFO("Interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
-#endif
         }
+
+        free(group->intl);
+        group->intl = NULL;
+        group->valid = 0;
+
         _pqos_api_unlock();
 
         return ret;
 }
 
 int
-pqos_mon_poll(struct pqos_mon_data **groups,
-              const unsigned num_groups)
+pqos_mon_poll(struct pqos_mon_data **groups, const unsigned num_groups)
 {
         int ret;
         unsigned i;
@@ -989,6 +1054,8 @@ pqos_mon_poll(struct pqos_mon_data **groups,
                         return PQOS_RETVAL_PARAM;
                 if (groups[i]->valid != GROUP_VALID_MARKER)
                         return PQOS_RETVAL_PARAM;
+                if (groups[i]->event == 0)
+                        return PQOS_RETVAL_PARAM;
         }
 
         _pqos_api_lock();
@@ -999,15 +1066,12 @@ pqos_mon_poll(struct pqos_mon_data **groups,
                 return ret;
         }
 
-        if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mon_poll(groups, num_groups);
-        else {
-#ifdef __linux__
-                ret = os_mon_poll(groups, num_groups);
-#else
-                LOG_INFO("OS interface not supported!\n");
-                ret = PQOS_RETVAL_RESOURCE;
-#endif
+        for (i = 0; i < num_groups; i++) {
+                int ret = pqos_mon_poll_events(groups[i]);
+
+                if (ret != PQOS_RETVAL_OK)
+                        LOG_WARN("Failed to poll event on group number %u\n",
+                                 i);
         }
         _pqos_api_unlock();
 
@@ -1038,13 +1102,6 @@ pqos_mon_start_pids(const unsigned num_pids,
         if (group->valid == GROUP_VALID_MARKER)
                 return PQOS_RETVAL_PARAM;
 
-        if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
-                LOG_ERROR("Incompatible interface "
-                          "selected for task monitoring!\n");
-                return PQOS_RETVAL_ERROR;
-        }
-
         /**
          * Validate event parameter
          * - only combinations of events allowed
@@ -1068,25 +1125,44 @@ pqos_mon_start_pids(const unsigned num_pids,
                 return ret;
         }
 
-#ifdef __linux__
-        ret = os_mon_start_pids(num_pids, pids, event, context, group);
-#else
-        UNUSED_PARAM(context);
-        LOG_INFO("OS interface not supported!\n");
-        ret = PQOS_RETVAL_RESOURCE;
-#endif
+        if (m_interface != PQOS_INTER_OS &&
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task monitoring!\n");
+                _pqos_api_unlock();
+                return PQOS_RETVAL_ERROR;
+        }
 
+        memset(group, 0, sizeof(*group));
+        group->intl = malloc(sizeof(*group->intl));
+        if (group->intl == NULL) {
+                ret = PQOS_RETVAL_RESOURCE;
+                goto pqos_mon_start_pids_exit;
+        }
+        memset(group->intl, 0, sizeof(*group->intl));
+
+        if (api.mon_start_pids != NULL)
+                ret = api.mon_start_pids(num_pids, pids, event, context, group);
+        else {
+                LOG_INFO("Interface not supported!\n");
+                ret = PQOS_RETVAL_RESOURCE;
+        }
+
+pqos_mon_start_pids_exit:
         if (ret == PQOS_RETVAL_OK)
                 group->valid = GROUP_VALID_MARKER;
+        else if (group->intl != NULL)
+                free(group->intl);
 
         _pqos_api_unlock();
 
         return ret;
 }
 
-int pqos_mon_add_pids(const unsigned num_pids,
-                      const pid_t *pids,
-                      struct pqos_mon_data *group)
+int
+pqos_mon_add_pids(const unsigned num_pids,
+                  const pid_t *pids,
+                  struct pqos_mon_data *group)
 {
         int ret;
 
@@ -1096,13 +1172,6 @@ int pqos_mon_add_pids(const unsigned num_pids,
         if (group->valid != GROUP_VALID_MARKER)
                 return PQOS_RETVAL_PARAM;
 
-        if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
-                LOG_ERROR("Incompatible interface "
-                          "selected for task monitoring!\n");
-                return PQOS_RETVAL_ERROR;
-        }
-
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -1111,6 +1180,14 @@ int pqos_mon_add_pids(const unsigned num_pids,
                 return ret;
         }
 
+        if (m_interface != PQOS_INTER_OS &&
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task monitoring!\n");
+                _pqos_api_unlock();
+                return PQOS_RETVAL_ERROR;
+        }
+
 #ifdef __linux__
         ret = os_mon_add_pids(num_pids, pids, group);
 #else
@@ -1123,9 +1200,10 @@ int pqos_mon_add_pids(const unsigned num_pids,
         return ret;
 }
 
-int pqos_mon_remove_pids(const unsigned num_pids,
-                         const pid_t *pids,
-                         struct pqos_mon_data *group)
+int
+pqos_mon_remove_pids(const unsigned num_pids,
+                     const pid_t *pids,
+                     struct pqos_mon_data *group)
 {
         int ret;
 
@@ -1135,13 +1213,6 @@ int pqos_mon_remove_pids(const unsigned num_pids,
         if (group->valid != GROUP_VALID_MARKER)
                 return PQOS_RETVAL_PARAM;
 
-        if (m_interface != PQOS_INTER_OS &&
-                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
-                LOG_ERROR("Incompatible interface "
-                          "selected for task monitoring!\n");
-                return PQOS_RETVAL_ERROR;
-        }
-
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -1150,6 +1221,14 @@ int pqos_mon_remove_pids(const unsigned num_pids,
                 return ret;
         }
 
+        if (m_interface != PQOS_INTER_OS &&
+            m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task monitoring!\n");
+                _pqos_api_unlock();
+                return PQOS_RETVAL_ERROR;
+        }
+
 #ifdef __linux__
         ret = os_mon_remove_pids(num_pids, pids, group);
 #else
