@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,19 +40,25 @@
 #include <stdint.h>
 #include <limits.h>
 #include <errno.h>
-#include <unistd.h>      /* sysconf() */
+#include <unistd.h> /* sysconf() */
 #ifdef __FreeBSD__
-#include <sys/param.h>   /* sched affinity */
-#include <sys/cpuset.h>  /* sched affinity */
+#include <sys/param.h>  /* sched affinity */
+#include <sys/cpuset.h> /* sched affinity */
 #endif
 #ifdef __linux__
-#include <sched.h>       /* sched affinity */
+#include <sched.h> /* sched affinity */
 #endif
 
+#include "pqos.h"
+
+#include "cpu_registers.h"
 #include "log.h"
 #include "cpuinfo.h"
 #include "types.h"
 #include "machine.h"
+#include "os_allocation.h"
+#include "allocation.h"
+#include "cap.h"
 
 /**
  * This structure will be made externally available
@@ -60,6 +66,11 @@
  */
 static struct pqos_cpuinfo *m_cpu = NULL;
 
+/**
+ * intel/amd vendor configuration
+ */
+static struct cpuinfo_config m_config;
+
 /**
  * L2 and L3 cache info structures
  */
@@ -169,7 +180,7 @@ detect_apic_core_masks(struct apic_info *apic)
         int thread_reported = 0;
         unsigned subleaf = 0;
 
-        for (subleaf = 0; ; subleaf++) {
+        for (subleaf = 0;; subleaf++) {
                 struct cpuid_out leafB;
                 unsigned level_type, level_shift;
                 uint32_t mask;
@@ -178,8 +189,8 @@ detect_apic_core_masks(struct apic_info *apic)
                 if (leafB.ebx == 0) /* invalid sub-leaf */
                         break;
 
-                level_type = (leafB.ecx >> 8) & 0xff;     /* ECX bits 15:8 */
-                level_shift = leafB.eax & 0x1f;           /* EAX bits 4:0 */
+                level_type = (leafB.ecx >> 8) & 0xff; /* ECX bits 15:8 */
+                level_shift = leafB.eax & 0x1f;       /* EAX bits 4:0 */
                 mask = ~(UINT32_MAX << level_shift);
 
                 if (level_type == 1) {
@@ -228,7 +239,7 @@ nearest_pow2(const unsigned n)
 {
         unsigned r, p;
 
-	if (n < 2)
+        if (n < 2)
                 return n;
 
         for (r = 1, p = 0; r != 0; r <<= 1, p++)
@@ -265,19 +276,19 @@ detect_apic_cache_masks(struct apic_info *apic, unsigned cpuid_cache)
         memset(&m_l2, 0, sizeof(m_l2));
         memset(&m_l3, 0, sizeof(m_l3));
 
-        for (subleaf = 0; ; subleaf++) {
+        for (subleaf = 0;; subleaf++) {
                 struct cpuid_out cache_info;
                 struct pqos_cacheinfo ci;
                 unsigned cache_type, cache_level, id, shift;
 
                 lcpuid(cpuid_cache, subleaf, &cache_info);
-                cache_type = cache_info.eax & 0x1f;	   /* EAX bits 04:00 */
+                cache_type = cache_info.eax & 0x1f;        /* EAX bits 04:00 */
                 cache_level = (cache_info.eax >> 5) & 0x7; /* EAX bits 07:05 */
                 id = (cache_info.eax >> 14) & 0xfff;       /* EAX bits 25:14 */
                 shift = nearest_pow2(id + 1);
 
                 if (cache_type == 0 || cache_type >= 4)
-                        break;    /* no more caches or reserved */
+                        break; /* no more caches or reserved */
 
                 if (cache_level < DIM(cache_level_shift))
                         cache_level_shift[cache_level] = shift;
@@ -298,8 +309,8 @@ detect_apic_cache_masks(struct apic_info *apic, unsigned cpuid_cache)
                 LOG_DEBUG("CACHE: %sinclusive, %s, %s%u way(s), "
                           "%u set(s), line size %u, %u partition(s)\n",
                           (cache_info.edx & 2) ? "" : "not ",
-                          (cache_info.edx & 4) ? "complex cache indexing" :
-                          "direct mapped",
+                          (cache_info.edx & 4) ? "complex cache indexing"
+                                               : "direct mapped",
                           (cache_info.eax & 0x200) ? "fully associative, " : "",
                           ci.num_ways, ci.num_sets, ci.line_size,
                           ci.num_partitions);
@@ -345,7 +356,7 @@ detect_apic_masks(struct apic_info *apic)
         if (detect_apic_core_masks(apic) != 0)
                 return -2;
 
-        if (detect_apic_cache_masks(apic, CPUID_LEAF_CACHE) != 0)
+        if (detect_apic_cache_masks(apic, m_config.cpuid_cache_leaf) != 0)
                 return -3;
 
         return 0;
@@ -372,7 +383,8 @@ detect_apic_masks(struct apic_info *apic)
 static int
 detect_cpu(const int cpu,
            const struct apic_info *apic,
-           struct pqos_coreinfo *info)
+           struct pqos_coreinfo *info,
+           enum pqos_vendor vendor)
 {
         struct cpuid_out leafB;
         uint32_t apicid;
@@ -381,27 +393,31 @@ detect_cpu(const int cpu,
                 return -1;
 
         lcpuid(0xb, 0, &leafB);
-        apicid = leafB.edx;        /* x2APIC ID */
+        apicid = leafB.edx; /* x2APIC ID */
 
         info->lcore = cpu;
         info->socket = (apicid & apic->pkg_mask) >> apic->pkg_shift;
         info->l3_id = apicid >> apic->l3_shift;
         info->l2_id = apicid >> apic->l2_shift;
 
-	/*
-	 * Update l3cat_id and mba_id. For Intel, CAT and MBA ids are
-	 * initialized to socket id. AMD uses l3_id for both CAT and MBA
-	 * ids. Right now, both these ids are same. This could change in
-	 * the future.
-	 */
+        /*
+         * Update l3cat_id and mba_id. For Intel, CAT and MBA ids are
+         * initialized to socket id. AMD uses l3_id for both CAT and MBA
+         * ids. Right now, both these ids are same. This could change in
+         * the future.
+         */
 
-	info->l3cat_id = info->socket;
-	info->mba_id = info->socket;
+        if (vendor == PQOS_VENDOR_AMD) {
+                info->l3cat_id = info->l3_id;
+                info->mba_id = info->l3_id;
+        } else {
+                info->l3cat_id = info->socket;
+                info->mba_id = info->socket;
+        }
 
         LOG_DEBUG("Detected core %u, socket %u, "
                   "L2 ID %u, L3 ID %u, APICID %u\n",
-                  info->lcore, info->socket,
-                  info->l2_id, info->l3_id, apicid);
+                  info->lcore, info->socket, info->l2_id, info->l3_id, apicid);
 
         return 0;
 }
@@ -422,7 +438,7 @@ detect_cpu(const int cpu,
  * @retval NULL on error
  */
 static struct pqos_cpuinfo *
-cpuinfo_build_topo(void)
+cpuinfo_build_topo(enum pqos_vendor vendor)
 {
         unsigned i, max_core_count, core_count = 0;
         struct pqos_cpuinfo *l_cpu = NULL;
@@ -445,19 +461,20 @@ cpuinfo_build_topo(void)
                 return NULL;
         }
 
-        const size_t mem_sz = sizeof(*l_cpu) +
-                (max_core_count * sizeof(struct pqos_coreinfo));
+        const size_t mem_sz =
+            sizeof(*l_cpu) + (max_core_count * sizeof(struct pqos_coreinfo));
 
         l_cpu = (struct pqos_cpuinfo *)malloc(mem_sz);
         if (l_cpu == NULL) {
                 LOG_ERROR("Couldn't allocate CPU topology structure!");
                 return NULL;
         }
-        l_cpu->mem_size = (unsigned) mem_sz;
+        l_cpu->mem_size = (unsigned)mem_sz;
         memset(l_cpu, 0, mem_sz);
 
         for (i = 0; i < max_core_count; i++)
-                if (detect_cpu(i, &apic, &l_cpu->cores[core_count]) == 0)
+                if (detect_cpu(i, &apic, &l_cpu->cores[core_count], vendor) ==
+                    0)
                         core_count++;
 
         if (set_affinity_mask(&current_mask) != 0) {
@@ -468,6 +485,7 @@ cpuinfo_build_topo(void)
 
         l_cpu->l2 = m_l2;
         l_cpu->l3 = m_l3;
+        l_cpu->vendor = vendor;
         l_cpu->num_cores = core_count;
         if (core_count == 0) {
                 free(l_cpu);
@@ -477,6 +495,68 @@ cpuinfo_build_topo(void)
         return l_cpu;
 }
 
+/**
+ * @brief Detects and returns the CPU vendor
+ *
+ * Sets the vendor identification. See pqos_vendor definitions.
+ *
+ * @return detected vendor
+ */
+static enum pqos_vendor
+detect_vendor(void)
+{
+        enum pqos_vendor cpu_vendor;
+        struct cpuid_out vendor;
+
+        lcpuid(0x0, 0x0, &vendor);
+        if (vendor.ebx == 0x756e6547 && vendor.edx == 0x49656e69 &&
+            vendor.ecx == 0x6c65746e) {
+                cpu_vendor = PQOS_VENDOR_INTEL;
+        } else if (vendor.ebx == 0x68747541 && vendor.edx == 0x69746E65 &&
+                   vendor.ecx == 0x444D4163) {
+                cpu_vendor = PQOS_VENDOR_AMD;
+        } else {
+                cpu_vendor = PQOS_VENDOR_UNKNOWN;
+        }
+        return cpu_vendor;
+}
+
+/**
+ * Initialize pointers for the vendors
+ *
+ * @param config configuration structures
+ * @param vendor identification
+ *
+ * @return Operation status
+ * @retval Success returns 0
+ */
+static int
+init_config(struct cpuinfo_config *config, enum pqos_vendor vendor)
+{
+        memset(config, 0, sizeof(struct cpuinfo_config));
+
+        /**
+         * Make sure to initialize all the pointers to avoid
+         * NULL check while calling
+         */
+        if (vendor == PQOS_VENDOR_INTEL) {
+                config->cpuid_cache_leaf = 4;
+                config->mba_max = PQOS_MBA_LINEAR_MAX;
+                config->mba_msr_reg = PQOS_MSR_MBA_MASK_START;
+                config->mba_default_val = 0;
+        } else if (vendor == PQOS_VENDOR_AMD) {
+                config->cpuid_cache_leaf = 0x8000001D;
+                config->mba_max = PQOS_MBA_MAX_AMD;
+                config->mba_msr_reg = PQOS_MSR_MBA_MASK_START_AMD;
+                config->mba_default_val = PQOS_MBA_MAX_AMD;
+        } else {
+                LOG_ERROR("init_config: init failed!");
+                return -EFAULT;
+        }
+
+        return 0;
+}
+
 /**
  * Detect number of logical processors on the machine
  * and their location.
@@ -484,18 +564,29 @@ cpuinfo_build_topo(void)
 int
 cpuinfo_init(const struct pqos_cpuinfo **topology)
 {
+        int ret;
+        enum pqos_vendor vendor;
+
         if (topology == NULL)
                 return -EINVAL;
 
         if (m_cpu != NULL)
                 return -EPERM;
 
-        m_cpu = cpuinfo_build_topo();
+        vendor = detect_vendor();
+
+        ret = init_config(&m_config, vendor);
+        if (ret != 0)
+                return ret;
+
+        m_cpu = cpuinfo_build_topo(vendor);
         if (m_cpu == NULL) {
                 LOG_ERROR("CPU topology detection error!");
                 return -EFAULT;
         }
 
+        m_cpu->vendor = vendor;
+
         *topology = m_cpu;
         return 0;
 }
@@ -509,3 +600,11 @@ cpuinfo_fini(void)
         m_cpu = NULL;
         return 0;
 }
+
+void
+cpuinfo_get_config(const struct cpuinfo_config **config)
+{
+        ASSERT(config != NULL);
+
+        *config = &m_config;
+}
