@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,6 +46,16 @@
 extern "C" {
 #endif
 
+/**
+ * CPU vendor configuration value
+ */
+struct cpuinfo_config {
+        int cpuid_cache_leaf;     /**< Cache mask leaf */
+        unsigned mba_max;         /**< default memory bandwidth */
+        unsigned mba_default_val; /**< Memory bandwidth reset value */
+        uint32_t mba_msr_reg;     /**< MBA mask base register */
+};
+
 /**
  * @brief Initializes CPU information module
  *
@@ -70,6 +80,13 @@ int cpuinfo_init(const struct pqos_cpuinfo **topology);
  */
 int cpuinfo_fini(void);
 
+/**
+ * @brief Internal API to retrieve PQoS vendor specific data
+ *
+ * @param [out] config location to store PQoS vendor specific information at
+ */
+void cpuinfo_get_config(const struct cpuinfo_config **config);
+
 #ifdef __cplusplus
 }
 #endif
