@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@
  * Local data types
  * ---------------------------------------
  */
-#define AP_BUFFER_SIZE  256
+#define AP_BUFFER_SIZE 256
 
 /**
  * ---------------------------------------
@@ -59,21 +59,20 @@
  * ---------------------------------------
  */
 
-static int m_opt = 0;                   /**< log options */
-static int m_fd = -1;			/**< log file descriptor */
-static void *m_context_log = NULL;      /**< log callback context */
+static int m_opt = 0;              /**< log options */
+static int m_fd = -1;              /**< log file descriptor */
+static void *m_context_log = NULL; /**< log callback context */
 /**
  *  log callback
  */
 static void (*m_callback_log)(void *, const size_t, const char *);
-static int log_init_successful = 0;     /**< log init gatekeeper */
+static int log_init_successful = 0; /**< log init gatekeeper */
 /**
  * ---------------------------------------
  * Local functions
  * ---------------------------------------
  */
 
-
 /**
  * =======================================
  * initialize and shutdown
@@ -81,17 +80,19 @@ static int log_init_successful = 0;     /**< log init gatekeeper */
  */
 
 int
-log_init(int fd_log, void (*callback_log)(void *, const size_t, const char *),
-        void *context_log, int verbosity)
+log_init(int fd_log,
+         void (*callback_log)(void *, const size_t, const char *),
+         void *context_log,
+         int verbosity)
 {
-	/**
+        /**
          * Set log message verbosity
          */
         switch (verbosity) {
         case LOG_VER_SILENT:
                 m_opt = LOG_OPT_SILENT;
                 log_init_successful = 1;
-		return LOG_RETVAL_OK;
+                return LOG_RETVAL_OK;
         case LOG_VER_DEFAULT:
                 m_opt = LOG_OPT_DEFAULT;
                 break;
@@ -106,16 +107,15 @@ log_init(int fd_log, void (*callback_log)(void *, const size_t, const char *),
                 break;
         }
 
-	if (fd_log < 0 && callback_log == NULL) {
-                fprintf(stderr, "%s: no LOG destination selected\n",
-                       __func__);
+        if (fd_log < 0 && callback_log == NULL) {
+                fprintf(stderr, "%s: no LOG destination selected\n", __func__);
                 return LOG_RETVAL_ERROR;
         }
 
-	m_fd = fd_log;
-	m_callback_log = callback_log;
-	m_context_log = context_log;
-	log_init_successful = 1;
+        m_fd = fd_log;
+        m_callback_log = callback_log;
+        m_context_log = context_log;
+        log_init_successful = 1;
 
         return LOG_RETVAL_OK;
 }
@@ -123,16 +123,16 @@ log_init(int fd_log, void (*callback_log)(void *, const size_t, const char *),
 int
 log_fini(void)
 {
-	if (m_opt == LOG_OPT_SILENT) {
+        if (m_opt == LOG_OPT_SILENT) {
                 log_init_successful = 0;
-		return LOG_RETVAL_OK;
+                return LOG_RETVAL_OK;
         }
 
         m_opt = 0;
-	m_fd = -1;
-	m_callback_log = NULL;
-	m_context_log = NULL;
-	log_init_successful = 0;
+        m_fd = -1;
+        m_callback_log = NULL;
+        m_context_log = NULL;
+        log_init_successful = 0;
 
         return LOG_RETVAL_OK;
 }
@@ -141,17 +141,17 @@ void
 log_printf(int type, const char *str, ...)
 {
         va_list ap;
-	char ap_buffer[AP_BUFFER_SIZE];
+        char ap_buffer[AP_BUFFER_SIZE];
         int size;
 
-	/* If log_init has not been successful then
-	 * log_printf should not work. */
+        /* If log_init has not been successful then
+         * log_printf should not work. */
         ASSERT(log_init_successful == 1);
-	if (log_init_successful == 0)
-		return;
+        if (log_init_successful == 0)
+                return;
 
-	if (m_opt == LOG_OPT_SILENT)
-		return;
+        if (m_opt == LOG_OPT_SILENT)
+                return;
 
         if ((m_opt & type) == 0)
                 return;
@@ -160,20 +160,20 @@ log_printf(int type, const char *str, ...)
         if (str == NULL)
                 return;
 
-	va_start(ap, str);
-	ap_buffer[AP_BUFFER_SIZE - 1] = '\0';
-	size = vsnprintf(ap_buffer, AP_BUFFER_SIZE - 1, str, ap);
-	va_end(ap);
-	ASSERT(size >= 0);
-	if (size < 0)
-		return;
+        va_start(ap, str);
+        ap_buffer[AP_BUFFER_SIZE - 1] = '\0';
+        size = vsnprintf(ap_buffer, AP_BUFFER_SIZE - 1, str, ap);
+        va_end(ap);
+        ASSERT(size >= 0);
+        if (size < 0)
+                return;
 
-	if (m_callback_log != NULL)
-		m_callback_log(m_context_log, size, ap_buffer);
+        if (m_callback_log != NULL)
+                m_callback_log(m_context_log, size, ap_buffer);
 
-	if (m_fd >= 0) {
-		if (write(m_fd, ap_buffer, size) < 0)
-			fprintf(stderr, "%s: printing to file failed\n",
+        if (m_fd >= 0) {
+                if (write(m_fd, ap_buffer, size) < 0)
+                        fprintf(stderr, "%s: printing to file failed\n",
                                 __func__);
-	}
+        }
 }
