@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,27 +34,29 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <dirent.h>             /**< scandir() */
+#include <dirent.h> /**< scandir() */
 #include <linux/perf_event.h>
+#include <sys/stat.h>
 
 #include "pqos.h"
 #include "common.h"
 #include "perf.h"
 #include "log.h"
 #include "types.h"
+#include "monitoring.h"
 #include "perf_monitoring.h"
 
 /**
  * Event indexes in table of supported events
  */
-#define OS_MON_EVT_IDX_LLC       0
-#define OS_MON_EVT_IDX_LMBM      1
-#define OS_MON_EVT_IDX_TMBM      2
-#define OS_MON_EVT_IDX_RMBM      3
-#define OS_MON_EVT_IDX_INST      4
-#define OS_MON_EVT_IDX_CYC       5
-#define OS_MON_EVT_IDX_IPC       6
-#define OS_MON_EVT_IDX_LLC_MISS  7
+#define OS_MON_EVT_IDX_LLC      0
+#define OS_MON_EVT_IDX_LMBM     1
+#define OS_MON_EVT_IDX_TMBM     2
+#define OS_MON_EVT_IDX_RMBM     3
+#define OS_MON_EVT_IDX_INST     4
+#define OS_MON_EVT_IDX_CYC      5
+#define OS_MON_EVT_IDX_IPC      6
+#define OS_MON_EVT_IDX_LLC_MISS 7
 
 /**
  * ---------------------------------------
@@ -66,6 +68,9 @@ static const struct pqos_cpuinfo *m_cpu = NULL;
 /**
  * Paths to RDT perf event info
  */
+#ifndef PERF_MON_SUPPORT
+#define PERF_MON_SUPPORT "/proc/sys/kernel/perf_event_paranoid"
+#endif
 static const char *perf_events = "events/";
 static const char *perf_type = "type";
 
@@ -92,42 +97,42 @@ static struct perf_mon_supported_event {
         double scale;
         struct perf_event_attr attrs;
 } events_tab[] = {
-        { .name = "llc_occupancy",
-          .desc = "LLC Occupancy",
-          .event = PQOS_MON_EVENT_L3_OCCUP,
-          .supported = 0,
-          .scale = 1 },
-        { .name = "local_bytes",
-          .desc = "Local Memory B/W",
-          .event = PQOS_MON_EVENT_LMEM_BW,
-          .supported = 0,
-          .scale = 1 },
-        { .name = "total_bytes",
-          .desc = "Total Memory B/W",
-          .event = PQOS_MON_EVENT_TMEM_BW,
-          .supported = 0,
-          .scale = 1 },
-        { .name = "",
-          .desc = "Remote Memory B/W",
-          .event = PQOS_MON_EVENT_RMEM_BW,
-          .supported = 0,
-          .scale = 1 },
-        { .name = "",
-          .desc = "Retired CPU Instructions",
-          .event = (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS,
-          .supported = 1 }, /**< assumed support */
-        { .name = "",
-          .desc = "Unhalted CPU Cycles",
-          .event = (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES,
-          .supported = 1 }, /**< assumed support */
-        { .name = "",
-          .desc = "Instructions/Cycle",
-          .event = PQOS_PERF_EVENT_IPC,
-          .supported = 1 }, /**< assumed support */
-        { .name = "",
-          .desc = "LLC Misses",
-          .event = PQOS_PERF_EVENT_LLC_MISS,
-          .supported = 1 }, /**< assumed support */
+    {.name = "llc_occupancy",
+     .desc = "LLC Occupancy",
+     .event = PQOS_MON_EVENT_L3_OCCUP,
+     .supported = 0,
+     .scale = 1},
+    {.name = "local_bytes",
+     .desc = "Local Memory B/W",
+     .event = PQOS_MON_EVENT_LMEM_BW,
+     .supported = 0,
+     .scale = 1},
+    {.name = "total_bytes",
+     .desc = "Total Memory B/W",
+     .event = PQOS_MON_EVENT_TMEM_BW,
+     .supported = 0,
+     .scale = 1},
+    {.name = "",
+     .desc = "Remote Memory B/W",
+     .event = PQOS_MON_EVENT_RMEM_BW,
+     .supported = 0,
+     .scale = 1},
+    {.name = "",
+     .desc = "Retired CPU Instructions",
+     .event = (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS,
+     .supported = 0},
+    {.name = "",
+     .desc = "Unhalted CPU Cycles",
+     .event = (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES,
+     .supported = 0},
+    {.name = "",
+     .desc = "Instructions/Cycle",
+     .event = PQOS_PERF_EVENT_IPC,
+     .supported = 0},
+    {.name = "",
+     .desc = "LLC Misses",
+     .event = PQOS_PERF_EVENT_LLC_MISS,
+     .supported = 0},
 };
 
 /**
@@ -168,9 +173,9 @@ get_supported_event(const enum pqos_mon_event event)
                 return &events_tab[OS_MON_EVT_IDX_TMBM];
         case PQOS_MON_EVENT_RMEM_BW:
                 return &events_tab[OS_MON_EVT_IDX_RMBM];
-        case (enum pqos_mon_event) PQOS_PERF_EVENT_INSTRUCTIONS:
+        case (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS:
                 return &events_tab[OS_MON_EVT_IDX_INST];
-        case (enum pqos_mon_event) PQOS_PERF_EVENT_CYCLES:
+        case (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES:
                 return &events_tab[OS_MON_EVT_IDX_CYC];
         case PQOS_PERF_EVENT_IPC:
                 return &events_tab[OS_MON_EVT_IDX_IPC];
@@ -194,13 +199,10 @@ set_mon_type(void)
         FILE *fd;
         char file[64], evt[8];
 
-        snprintf(file, sizeof(file) - 1, "%s%s", PERF_MON_PATH, perf_type);
-        fd = fopen_check_symlink(file, "r");
-        if (fd == NULL) {
-                LOG_INFO("Perf monitoring not supported. "
-                         "Kernel version 4.6 or higher required.\n");
+        snprintf(file, sizeof(file) - 1, "%s/%s", PERF_MON_PATH, perf_type);
+        fd = pqos_fopen(file, "r");
+        if (fd == NULL)
                 return PQOS_RETVAL_RESOURCE;
-        }
         if (fgets(evt, sizeof(evt), fd) == NULL) {
                 LOG_ERROR("Failed to read perf monitoring type!\n");
                 fclose(fd);
@@ -208,7 +210,7 @@ set_mon_type(void)
         }
         fclose(fd);
 
-        os_mon_type = (int) strtol(evt, NULL, 0);
+        os_mon_type = (int)strtol(evt, NULL, 0);
         if (os_mon_type == 0) {
                 LOG_ERROR("Failed to convert perf monitoring type!\n");
                 return PQOS_RETVAL_ERROR;
@@ -242,19 +244,18 @@ set_arch_event_attrs(enum pqos_mon_event *events)
         /* Set LLC misses event attributes */
         events_tab[OS_MON_EVT_IDX_LLC_MISS].attrs = attr;
         events_tab[OS_MON_EVT_IDX_LLC_MISS].attrs.config =
-                PERF_COUNT_HW_CACHE_MISSES;
+            PERF_COUNT_HW_CACHE_MISSES;
         *events |= (enum pqos_mon_event)PQOS_PERF_EVENT_LLC_MISS;
 
         /* Set retired instructions event attributes */
         events_tab[OS_MON_EVT_IDX_INST].attrs = attr;
         events_tab[OS_MON_EVT_IDX_INST].attrs.config =
-                PERF_COUNT_HW_INSTRUCTIONS;
+            PERF_COUNT_HW_INSTRUCTIONS;
         *events |= (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS;
 
         /* Set unhalted cycles event attributes */
         events_tab[OS_MON_EVT_IDX_CYC].attrs = attr;
-        events_tab[OS_MON_EVT_IDX_CYC].attrs.config =
-                PERF_COUNT_HW_CPU_CYCLES;
+        events_tab[OS_MON_EVT_IDX_CYC].attrs.config = PERF_COUNT_HW_CPU_CYCLES;
         *events |= (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES;
 
         *events |= (enum pqos_mon_event)PQOS_PERF_EVENT_IPC;
@@ -285,9 +286,9 @@ set_rdt_event_attrs(const int idx, const char *fname)
         /**
          * Read event type from file system
          */
-        snprintf(file, sizeof(file) - 1, "%s%s%s", PERF_MON_PATH, perf_events,
+        snprintf(file, sizeof(file) - 1, "%s/%s%s", PERF_MON_PATH, perf_events,
                  fname);
-        fd = fopen_check_symlink(file, "r");
+        fd = pqos_fopen(file, "r");
         if (fd == NULL) {
                 LOG_ERROR("Failed to open %s!\n", file);
                 return PQOS_RETVAL_ERROR;
@@ -310,9 +311,9 @@ set_rdt_event_attrs(const int idx, const char *fname)
         /**
          * Read scale factor from file system
          */
-        snprintf(file, sizeof(file) - 1, "%s%s%s.scale",
-                 PERF_MON_PATH, perf_events, fname);
-        fd = fopen_check_symlink(file, "r");
+        snprintf(file, sizeof(file) - 1, "%s/%s%s.scale", PERF_MON_PATH,
+                 perf_events, fname);
+        fd = pqos_fopen(file, "r");
         if (fd == NULL) {
                 LOG_ERROR("Failed to open OS monitoring event scale file!\n");
                 return PQOS_RETVAL_ERROR;
@@ -356,7 +357,7 @@ set_mon_events(void)
         /**
          * Read and store event data in table
          */
-        snprintf(dir, sizeof(dir) - 1, "%s%s", PERF_MON_PATH, perf_events);
+        snprintf(dir, sizeof(dir) - 1, "%s/%s", PERF_MON_PATH, perf_events);
         files = scandir(dir, &namelist, filter, NULL);
         if (files <= 0) {
                 LOG_ERROR("Failed to read perf monitoring events directory!\n");
@@ -372,12 +373,12 @@ set_mon_events(void)
                  * so, set up event attributes
                  */
                 for (j = 0; j < DIM(events_tab); j++) {
-                        if ((strcmp(events_tab[j].name,
-                                    namelist[i]->d_name)) != 0)
+                        if ((strcmp(events_tab[j].name, namelist[i]->d_name)) !=
+                            0)
                                 continue;
 
-                        if (set_rdt_event_attrs(j, namelist[i]->d_name)
-                            != PQOS_RETVAL_OK) {
+                        if (set_rdt_event_attrs(j, namelist[i]->d_name) !=
+                            PQOS_RETVAL_OK) {
                                 ret = PQOS_RETVAL_ERROR;
                                 goto init_pqos_events_exit;
                         }
@@ -401,7 +402,7 @@ set_mon_events(void)
 
         all_evt_mask |= events;
 
- init_pqos_events_exit:
+init_pqos_events_exit:
         if (files > 0) {
                 for (i = 0; i < files; i++)
                         free(namelist[i]);
@@ -410,15 +411,32 @@ set_mon_events(void)
         return ret;
 }
 
-int perf_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
+int
+perf_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
 {
         int ret;
         unsigned i;
+        struct stat st;
 
         ASSERT(cpu != NULL);
 
         UNUSED_PARAM(cap);
 
+        /**
+         * Perf monitoring not supported
+         */
+        if (stat(PERF_MON_SUPPORT, &st) != 0) {
+                LOG_INFO("Perf monitoring not supported.");
+                return PQOS_RETVAL_RESOURCE;
+
+        } else {
+                /* basic perf events are supported */
+                events_tab[OS_MON_EVT_IDX_INST].supported = 1;
+                events_tab[OS_MON_EVT_IDX_CYC].supported = 1;
+                events_tab[OS_MON_EVT_IDX_IPC].supported = 1;
+                events_tab[OS_MON_EVT_IDX_LLC_MISS].supported = 1;
+        }
+
         ret = set_arch_event_attrs(&all_evt_mask);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -433,7 +451,7 @@ int perf_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
- perf_mon_init_exit:
+perf_mon_init_exit:
         for (i = 0; i < DIM(events_tab); i++) {
                 if (!events_tab[i].supported)
                         continue;
@@ -483,7 +501,8 @@ perf_mon_start(struct pqos_mon_data *group, enum pqos_mon_event event)
         struct perf_mon_supported_event *se;
 
         ASSERT(group != NULL);
-        ASSERT(group->perf != NULL);
+        ASSERT(group->intl != NULL);
+        ASSERT(group->intl->perf.ctx != NULL);
 
         /**
          * Check if monitoring cores/tasks
@@ -504,7 +523,7 @@ perf_mon_start(struct pqos_mon_data *group, enum pqos_mon_event event)
          */
         for (i = 0; i < num_ctrs; i++) {
                 int ret;
-                struct pqos_mon_perf_ctx *ctx = &group->perf[i];
+                struct pqos_mon_perf_ctx *ctx = &group->intl->perf.ctx[i];
                 int *fd;
                 int core = -1;
                 pid_t tid = -1;
@@ -524,7 +543,8 @@ perf_mon_start(struct pqos_mon_data *group, enum pqos_mon_event event)
                 ret = perf_setup_counter(&se->attrs, tid, core, -1, 0, fd);
                 if (ret != PQOS_RETVAL_OK) {
                         LOG_ERROR("Failed to start perf "
-                                  "counters for %s\n", se->desc);
+                                  "counters for %s\n",
+                                  se->desc);
                         return PQOS_RETVAL_ERROR;
                 }
         }
@@ -538,7 +558,8 @@ perf_mon_stop(struct pqos_mon_data *group, enum pqos_mon_event event)
         int i, num_ctrs;
 
         ASSERT(group != NULL);
-        ASSERT(group->perf != NULL);
+        ASSERT(group->intl != NULL);
+        ASSERT(group->intl->perf.ctx != NULL);
 
         /**
          * Check if monitoring cores/tasks
@@ -554,7 +575,7 @@ perf_mon_stop(struct pqos_mon_data *group, enum pqos_mon_event event)
          * For each counter, close associated file descriptor
          */
         for (i = 0; i < num_ctrs; i++) {
-                struct pqos_mon_perf_ctx *ctx = &group->perf[i];
+                struct pqos_mon_perf_ctx *ctx = &group->intl->perf.ctx[i];
                 int *fd = perf_mon_get_fd(ctx, event);
 
                 if (fd == NULL)
@@ -592,7 +613,8 @@ perf_mon_poll(struct pqos_mon_data *group, enum pqos_mon_event event)
         uint64_t old_value;
 
         ASSERT(group != NULL);
-        ASSERT(group->perf != NULL);
+        ASSERT(group->intl != NULL);
+        ASSERT(group->intl->perf.ctx != NULL);
 
         /**
          * Check if monitoring cores/tasks
@@ -608,7 +630,7 @@ perf_mon_poll(struct pqos_mon_data *group, enum pqos_mon_event event)
          * For each task read counter and sum of all counter values
          */
         for (i = 0; i < num_ctrs; i++) {
-                struct pqos_mon_perf_ctx *ctx = &group->perf[i];
+                struct pqos_mon_perf_ctx *ctx = &group->intl->perf.ctx[i];
                 uint64_t counter_value;
                 int *fd = perf_mon_get_fd(ctx, event);
 
@@ -632,31 +654,31 @@ perf_mon_poll(struct pqos_mon_data *group, enum pqos_mon_event event)
                 old_value = group->values.mbm_local;
                 group->values.mbm_local = value;
                 group->values.mbm_local_delta =
-                        get_delta(old_value, group->values.mbm_local);
+                    get_delta(old_value, group->values.mbm_local);
                 break;
         case PQOS_MON_EVENT_TMEM_BW:
                 old_value = group->values.mbm_total;
                 group->values.mbm_total = value;
                 group->values.mbm_total_delta =
-                        get_delta(old_value, group->values.mbm_total);
+                    get_delta(old_value, group->values.mbm_total);
                 break;
         case PQOS_PERF_EVENT_LLC_MISS:
                 old_value = group->values.llc_misses;
                 group->values.llc_misses = value;
                 group->values.llc_misses_delta =
-                        get_delta(old_value, group->values.llc_misses);
+                    get_delta(old_value, group->values.llc_misses);
                 break;
         case (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES:
                 old_value = group->values.ipc_unhalted;
                 group->values.ipc_unhalted = value;
                 group->values.ipc_unhalted_delta =
-                        get_delta(old_value, group->values.ipc_unhalted);
+                    get_delta(old_value, group->values.ipc_unhalted);
                 break;
         case (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS:
                 old_value = group->values.ipc_retired;
                 group->values.ipc_retired = value;
                 group->values.ipc_retired_delta =
-                        get_delta(old_value, group->values.ipc_retired);
+                    get_delta(old_value, group->values.ipc_retired);
                 break;
         default:
                 return PQOS_RETVAL_ERROR;
