@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,15 +48,15 @@ extern "C" {
 #ifndef RESCTRL_PATH
 #define RESCTRL_PATH "/sys/fs/resctrl"
 #endif
-#define RESCTRL_PATH_INFO RESCTRL_PATH "/info"
+#define RESCTRL_PATH_INFO        RESCTRL_PATH "/info"
 #define RESCTRL_PATH_INFO_L3_MON RESCTRL_PATH_INFO "/L3_MON"
-#define RESCTRL_PATH_INFO_L3 RESCTRL_PATH_INFO "/L3"
+#define RESCTRL_PATH_INFO_L3     RESCTRL_PATH_INFO "/L3"
 #define RESCTRL_PATH_INFO_L3CODE RESCTRL_PATH_INFO "/L3CODE"
 #define RESCTRL_PATH_INFO_L3DATA RESCTRL_PATH_INFO "/L3DATA"
-#define RESCTRL_PATH_INFO_L2 RESCTRL_PATH_INFO "/L2"
+#define RESCTRL_PATH_INFO_L2     RESCTRL_PATH_INFO "/L2"
 #define RESCTRL_PATH_INFO_L2CODE RESCTRL_PATH_INFO "/L2CODE"
 #define RESCTRL_PATH_INFO_L2DATA RESCTRL_PATH_INFO "/L2DATA"
-#define RESCTRL_PATH_INFO_MB RESCTRL_PATH_INFO "/MB"
+#define RESCTRL_PATH_INFO_MB     RESCTRL_PATH_INFO "/MB"
 
 /**
  * Max supported number of CPU's
@@ -131,6 +131,14 @@ struct resctrl_cpumask {
  */
 void resctrl_cpumask_set(const unsigned lcore, struct resctrl_cpumask *mask);
 
+/**
+ * @brief Unset lcore bit in cpu mask
+ *
+ * @param [in] lcore Core number
+ * @param [in] cpumask Modified cpu mask
+ */
+void resctrl_cpumask_unset(const unsigned lcore, struct resctrl_cpumask *mask);
+
 /**
  * @brief Check if lcore is set in cpu mask
  *
