@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,18 +39,13 @@
 #include <dirent.h>
 
 #include "common.h"
+#include "allocation.h"
 #include "log.h"
 #include "types.h"
 #include "cap.h"
 #include "resctrl_alloc.h"
 #include "resctrl_utils.h"
-
-/**
- * ---------------------------------------
- * Local data structures
- * ---------------------------------------
- */
-static const struct pqos_cpuinfo *m_cpu = NULL;
+#include "resctrl_monitoring.h"
 
 /*
  * COS file names on resctrl file system
@@ -65,15 +60,12 @@ resctrl_alloc_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         if (cpu == NULL || cap == NULL)
                 return PQOS_RETVAL_PARAM;
 
-        m_cpu = cpu;
-
         return PQOS_RETVAL_OK;
 }
 
 int
 resctrl_alloc_fini(void)
 {
-        m_cpu = NULL;
         return PQOS_RETVAL_OK;
 }
 
@@ -133,6 +125,66 @@ resctrl_alloc_get_grps_num(const struct pqos_cap *cap, unsigned *grps_num)
         return PQOS_RETVAL_OK;
 }
 
+/**
+ * @brief Filter directory filenames
+ *
+ * This function is used by the scandir function
+ * to filter hidden (dot) files
+ *
+ * @param dir dirent structure containing directory info
+ *
+ * @return if directory entry should be included in scandir() output list
+ * @retval 0 means don't include the entry  ("." in our case)
+ * @retval 1 means include the entry
+ */
+static int
+filter(const struct dirent *dir)
+{
+        return (dir->d_name[0] == '.') ? 0 : 1;
+}
+
+int
+resctrl_alloc_get_num_closids(unsigned *num_closids)
+{
+        int ret = PQOS_RETVAL_OK;
+        struct dirent **namelist = NULL;
+        int i;
+        int num_info;
+
+        *num_closids = 0;
+
+        num_info = scandir(RESCTRL_PATH_INFO, &namelist, filter, NULL);
+        if (num_info <= 0) {
+                LOG_ERROR("Failed to read resctrl info dir!\n");
+                return PQOS_RETVAL_ERROR;
+        }
+
+        for (i = 0; i < num_info; ++i) {
+                char path[512];
+
+                snprintf(path, sizeof(path) - 1, "%s/%s/num_closids",
+                         RESCTRL_PATH_INFO, namelist[i]->d_name);
+
+                if (pqos_file_exists(path)) {
+                        uint64_t num;
+
+                        ret = pqos_fread_uint64(path, 10, &num);
+                        if (ret != PQOS_RETVAL_OK)
+                                return ret;
+
+                        if (num < *num_closids || *num_closids == 0)
+                                *num_closids = num;
+                }
+        }
+
+        for (i = 0; i < num_info; i++)
+                free(namelist[i]);
+
+        free(namelist);
+
+        return ret;
+}
+
 FILE *
 resctrl_alloc_fopen(const unsigned class_id, const char *name, const char *mode)
 {
@@ -154,7 +206,7 @@ resctrl_alloc_fopen(const unsigned class_id, const char *name, const char *mode)
         if (result < 0)
                 return NULL;
 
-        fd = fopen_check_symlink(buf, mode);
+        fd = pqos_fopen(buf, mode);
         if (fd == NULL)
                 LOG_ERROR("Could not open %s file %s for COS %u\n", name, buf,
                           class_id);
@@ -162,15 +214,7 @@ resctrl_alloc_fopen(const unsigned class_id, const char *name, const char *mode)
         return fd;
 }
 
-/**
- * @brief Closes COS file in resctl filesystem
- *
- * @param[in] fd File descriptor
- *
- * @return Operational status
- * @retval PQOS_RETVAL_OK on success
- */
-static int
+int
 resctrl_alloc_fclose(FILE *fd)
 {
         if (fd == NULL)
@@ -267,6 +311,7 @@ resctrl_alloc_schemata_read_exit:
 
 int
 resctrl_alloc_schemata_write(const unsigned class_id,
+                             const unsigned technology,
                              const struct resctrl_schemata *schemata)
 {
         int ret = PQOS_RETVAL_OK;
@@ -294,7 +339,18 @@ resctrl_alloc_schemata_write(const unsigned class_id,
                 goto resctrl_alloc_schemata_write_exit;
         }
 
-        ret = resctrl_schemata_write(fd, schemata);
+        if ((technology & PQOS_TECHNOLOGY_L3CA) == PQOS_TECHNOLOGY_L3CA) {
+                ret = resctrl_schemata_l3ca_write(fd, schemata);
+                if (ret != PQOS_RETVAL_OK)
+                        goto resctrl_alloc_schemata_write_exit;
+        }
+        if ((technology & PQOS_TECHNOLOGY_L2CA) == PQOS_TECHNOLOGY_L2CA) {
+                ret = resctrl_schemata_l2ca_write(fd, schemata);
+                if (ret != PQOS_RETVAL_OK)
+                        goto resctrl_alloc_schemata_write_exit;
+        }
+        if ((technology & PQOS_TECHNOLOGY_MBA) == PQOS_TECHNOLOGY_MBA)
+                ret = resctrl_schemata_mba_write(fd, schemata);
 
 resctrl_alloc_schemata_write_exit:
 
@@ -507,8 +563,12 @@ resctrl_alloc_task_file_check(const unsigned class_id, unsigned *found)
 int
 resctrl_alloc_assoc_set(const unsigned lcore, const unsigned class_id)
 {
-        int ret;
+        int ret, ret_mon;
         struct resctrl_cpumask mask;
+        char name[32];
+
+        /* check if core is assigned to monitoring group */
+        ret_mon = resctrl_mon_assoc_get(lcore, name, DIM(name));
 
         ret = resctrl_alloc_cpumask_read(class_id, &mask);
         if (ret != PQOS_RETVAL_OK)
@@ -518,6 +578,10 @@ resctrl_alloc_assoc_set(const unsigned lcore, const unsigned class_id)
 
         ret = resctrl_alloc_cpumask_write(class_id, &mask);
 
+        /* assign core back to monitoring group */
+        if (ret_mon == PQOS_RETVAL_OK)
+                resctrl_mon_assoc_set(lcore, name);
+
         return ret;
 }
 
