@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,7 @@
 #ifndef __PQOS_RESCTRL_ALLOC_H__
 #define __PQOS_RESCTRL_ALLOC_H__
 
+#include "types.h"
 #include "pqos.h"
 #include "resctrl.h"
 #include "resctrl_schemata.h"
@@ -56,8 +57,8 @@ extern "C" {
  * @return Operational status
  * @retval PQOS_RETVAL_OK success
  */
-int resctrl_alloc_init(const struct pqos_cpuinfo *cpu,
-                       const struct pqos_cap *cap);
+PQOS_LOCAL int resctrl_alloc_init(const struct pqos_cpuinfo *cpu,
+                                  const struct pqos_cap *cap);
 
 /**
  * @brief Shuts down resctrl allocation sub-module for OS allocation
@@ -65,7 +66,17 @@ int resctrl_alloc_init(const struct pqos_cpuinfo *cpu,
  * @return Operation status
  * @retval PQOS_RETVAL_OK success
  */
-int resctrl_alloc_fini(void);
+PQOS_LOCAL int resctrl_alloc_fini(void);
+
+/**
+ * @brief Retrieves number of resctrl closids
+ *
+ * @param [out] num_closids place to store retrieved value
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK on success
+ */
+PQOS_LOCAL int resctrl_alloc_get_num_closids(unsigned *num_closids);
 
 /**
  * @brief Retrieves number of resctrl groups allowed
@@ -76,7 +87,8 @@ int resctrl_alloc_fini(void);
  *
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_get_grps_num(const struct pqos_cap *cap, unsigned *grps_num);
+PQOS_LOCAL int resctrl_alloc_get_grps_num(const struct pqos_cap *cap,
+                                          unsigned *grps_num);
 
 /**
  * @brief Opens COS file in resctl filesystem
@@ -89,9 +101,19 @@ int resctrl_alloc_get_grps_num(const struct pqos_cap *cap, unsigned *grps_num);
  * @retval Pointer on success
  * @retval NULL on error
  */
-FILE *resctrl_alloc_fopen(const unsigned class_id,
-                          const char *name,
-                          const char *mode);
+PQOS_LOCAL FILE *resctrl_alloc_fopen(const unsigned class_id,
+                                     const char *name,
+                                     const char *mode);
+
+/**
+ * @brief Closes COS file in resctl filesystem
+ *
+ * @param[in] fd File descriptor
+ *
+ * @return Operational status
+ * @retval PQOS_RETVAL_OK on success
+ */
+PQOS_LOCAL int resctrl_alloc_fclose(FILE *fd);
 
 /**
  * @brief Write CPU mask to file
@@ -102,8 +124,8 @@ FILE *resctrl_alloc_fopen(const unsigned class_id,
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_cpumask_write(const unsigned class_id,
-                                const struct resctrl_cpumask *mask);
+PQOS_LOCAL int resctrl_alloc_cpumask_write(const unsigned class_id,
+                                           const struct resctrl_cpumask *mask);
 
 /**
  * @brief Read CPU mask from file
@@ -114,8 +136,8 @@ int resctrl_alloc_cpumask_write(const unsigned class_id,
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_cpumask_read(const unsigned class_id,
-                               struct resctrl_cpumask *mask);
+PQOS_LOCAL int resctrl_alloc_cpumask_read(const unsigned class_id,
+                                          struct resctrl_cpumask *mask);
 
 /**
  * @brief Read resctrl schemata from file
@@ -126,20 +148,24 @@ int resctrl_alloc_cpumask_read(const unsigned class_id,
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_schemata_read(const unsigned class_id,
-                                struct resctrl_schemata *schemata);
+PQOS_LOCAL int resctrl_alloc_schemata_read(const unsigned class_id,
+                                           struct resctrl_schemata *schemata);
 
 /**
  * @brief Write resctrl schemata to file
  *
  * @param [in] class_id COS id
+ * @param [in] technology bit mask selecting technologies
+ *             (1 << enum pqos_cap_type)
  * @param [in] schemata Schemata to write
  *
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_schemata_write(const unsigned class_id,
-                                 const struct resctrl_schemata *schemata);
+PQOS_LOCAL int
+resctrl_alloc_schemata_write(const unsigned class_id,
+                             const unsigned technology,
+                             const struct resctrl_schemata *schemata);
 
 /**
  * @brief Function to validate if \a task is a valid task ID
@@ -149,7 +175,7 @@ int resctrl_alloc_schemata_write(const unsigned class_id,
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_task_validate(const pid_t task);
+PQOS_LOCAL int resctrl_alloc_task_validate(const pid_t task);
 
 /**
  * @brief Function to write task ID to resctrl COS tasks file
@@ -161,7 +187,8 @@ int resctrl_alloc_task_validate(const pid_t task);
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_task_write(const unsigned class_id, const pid_t task);
+PQOS_LOCAL int resctrl_alloc_task_write(const unsigned class_id,
+                                        const pid_t task);
 
 /**
  * @brief Reads task id's from resctrl task file for a given COS
@@ -172,7 +199,8 @@ int resctrl_alloc_task_write(const unsigned class_id, const pid_t task);
  * @return Allocated task id array
  * @retval NULL on error
  */
-unsigned *resctrl_alloc_task_read(unsigned class_id, unsigned *count);
+PQOS_LOCAL unsigned *resctrl_alloc_task_read(unsigned class_id,
+                                             unsigned *count);
 
 /**
  * @brief Function to search a COS tasks file for a task ID
@@ -185,9 +213,9 @@ unsigned *resctrl_alloc_task_read(unsigned class_id, unsigned *count);
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_task_search(unsigned *class_id,
-                              const struct pqos_cap *cap,
-                              const pid_t task);
+PQOS_LOCAL int resctrl_alloc_task_search(unsigned *class_id,
+                                         const struct pqos_cap *cap,
+                                         const pid_t task);
 
 /**
  * @brief Function to search a COS tasks file and check if this file is blank
@@ -199,7 +227,8 @@ int resctrl_alloc_task_search(unsigned *class_id,
  *
  * @return Operation status
  */
-int resctrl_alloc_task_file_check(const unsigned class_id, unsigned *found);
+PQOS_LOCAL int resctrl_alloc_task_file_check(const unsigned class_id,
+                                             unsigned *found);
 
 /**
  * @brief Resctrl interface to associate \a lcore
@@ -210,7 +239,8 @@ int resctrl_alloc_task_file_check(const unsigned class_id, unsigned *found);
  *
  * @return Operations status
  */
-int resctrl_alloc_assoc_set(const unsigned lcore, const unsigned class_id);
+PQOS_LOCAL int resctrl_alloc_assoc_set(const unsigned lcore,
+                                       const unsigned class_id);
 
 /**
  * @brief Resctrl interface to read association
@@ -222,7 +252,8 @@ int resctrl_alloc_assoc_set(const unsigned lcore, const unsigned class_id);
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_assoc_get(const unsigned lcore, unsigned *class_id);
+PQOS_LOCAL int resctrl_alloc_assoc_get(const unsigned lcore,
+                                       unsigned *class_id);
 
 /**
  * @brief Resctrl interface to associate \a task
@@ -234,7 +265,8 @@ int resctrl_alloc_assoc_get(const unsigned lcore, unsigned *class_id);
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_assoc_set_pid(const pid_t task, const unsigned class_id);
+PQOS_LOCAL int resctrl_alloc_assoc_set_pid(const pid_t task,
+                                           const unsigned class_id);
 
 /**
  * @brief Resctrl interface to read association
@@ -246,7 +278,8 @@ int resctrl_alloc_assoc_set_pid(const pid_t task, const unsigned class_id);
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
  */
-int resctrl_alloc_assoc_get_pid(const pid_t task, unsigned *class_id);
+PQOS_LOCAL int resctrl_alloc_assoc_get_pid(const pid_t task,
+                                           unsigned *class_id);
 
 /**
  * @brief Gets unused resctrl group
@@ -258,7 +291,8 @@ int resctrl_alloc_assoc_get_pid(const pid_t task, unsigned *class_id);
  *
  * @return Operation status
  */
-int resctrl_alloc_get_unused_group(const unsigned grps_num, unsigned *group_id);
+PQOS_LOCAL int resctrl_alloc_get_unused_group(const unsigned grps_num,
+                                              unsigned *group_id);
 
 #ifdef __cplusplus
 }
