@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -191,6 +191,8 @@ set_l3_cos(const unsigned class_id, const uint64_t mask,
                 unsigned j, num_ca;
                 struct pqos_l3ca ca, sock_l3ca[PQOS_MAX_L3CA_COS];
 
+                memset(&ca, 0, sizeof(ca));
+
                 /* get current L3 definitions for this socket */
                 ret = pqos_l3ca_get(sock_ids[i], DIM(sock_l3ca),
                                     &num_ca, sock_l3ca);
@@ -285,6 +287,8 @@ set_l2_cos(const unsigned class_id,
                 unsigned j, num_ca;
                 struct pqos_l2ca ca, cluster_l2ca[PQOS_MAX_L2CA_COS];
 
+                memset(&ca, 0, sizeof(ca));
+
                 /* get current L2 definitions for this cluster */
                 ret = pqos_l2ca_get(l2_ids[i], DIM(cluster_l2ca),
                                     &num_ca, cluster_l2ca);
@@ -652,7 +656,6 @@ set_allocation_assoc(void)
         for (i = 0; i < sel_assoc_core_num; i++) {
                 ret = pqos_alloc_assoc_set(sel_assoc_tab[i].core,
                                            sel_assoc_tab[i].class_id);
-                ASSERT(ret == PQOS_RETVAL_OK);
                 if (ret == PQOS_RETVAL_PARAM) {
                         printf("Core number or class id is out of bounds!\n");
                         return -1;
@@ -666,7 +669,6 @@ set_allocation_assoc(void)
         for (i = 0; i < sel_assoc_pid_num; i++) {
                 ret = pqos_alloc_assoc_set_pid(sel_assoc_pid_tab[i].task_id,
                                                sel_assoc_pid_tab[i].class_id);
-                ASSERT(ret == PQOS_RETVAL_OK);
                 if (ret == PQOS_RETVAL_PARAM) {
                         printf("Task ID number or class id is out of "
                                "bounds!\n");
@@ -943,12 +945,16 @@ print_l2ca_config(const struct pqos_l2ca *ca, const int is_error)
 static void
 print_per_socket_config(const struct pqos_capability *cap_l3ca,
                         const struct pqos_capability *cap_mba,
+                        const struct pqos_cpuinfo *cpu_info,
                         const unsigned sock_count,
                         const unsigned *sockets)
 {
         int ret;
         unsigned i;
 
+        if (cpu_info == NULL || sockets == NULL)
+                return;
+
         if (cap_l3ca == NULL && cap_mba == NULL)
                 return;
 
@@ -988,8 +994,11 @@ print_per_socket_config(const struct pqos_capability *cap_l3ca,
                                 unit = " MBps";
                                 available = "";
                         } else {
-                                unit = "%";
                                 available = " available";
+                                if (cpu_info->vendor == PQOS_VENDOR_AMD)
+                                        unit = "";
+                                else
+                                        unit = "%";
                         }
 
                         ret = pqos_mba_get(sockets[i], mba->num_classes,
@@ -1070,7 +1079,8 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
 		return;
 	}
 
-        print_per_socket_config(cap_l3ca, cap_mba, sock_count, sockets);
+        print_per_socket_config(cap_l3ca, cap_mba, cpu_info, sock_count,
+                                sockets);
 
         if (cap_l2ca != NULL) {
                 /* Print L2 CAT class definitions per L2 cluster */
