@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -570,7 +570,7 @@ parse_config_file(const char *fname)
         FILE *fp = NULL;
         char cb[256];
 
-        fp = fopen_check_symlink(fname, "r");
+        fp = safe_fopen(fname, "r");
         if (fp == NULL)
                 parse_error(fname, "cannot open configuration file!");
 
@@ -632,7 +632,7 @@ parse_config_file(const char *fname)
 static const char *m_cmd_name = "pqos";                     /**< command name */
 static const char help_printf_short[] =
         "Usage: %s [-h] [--help] [-v] [--verbose] [-V] [--super-verbose]\n"
-        "       %s [-w] [--version]\n"
+        "       %s [--version]\n"
         "          [-l FILE] [--log-file=FILE] [-I] [--iface-os]\n"
         "       %s [-s] [--show]\n"
         "       %s [-d] [--display] [-D] [--display-verbose]\n"
@@ -641,6 +641,7 @@ static const char help_printf_short[] =
 #ifdef PQOS_RMID_CUSTOM
         "       %s [--rmid=RMIDCORES]\n"
 #endif
+        "       %s [--disable-mon-ipc] [--disable-mon-llc_miss]"
         "          [-t SECONDS] [--mon-time=SECONDS]\n"
         "          [-i N] [--mon-interval=N]\n"
         "          [-T] [--mon-top]\n"
@@ -660,7 +661,7 @@ static const char help_printf_long[] =
         "  -h, --help                  help page\n"
         "  -v, --verbose               verbose mode\n"
         "  -V, --super-verbose         super-verbose mode\n"
-        "  -w, --version               show PQoS library version\n"
+        "  --version                   show PQoS library version\n"
         "  -s, --show                  show current PQoS configuration\n"
         "  -d, --display               display supported capabilities\n"
         "  -D, --display-verbose       display supported capabilities in verbose mode\n"
@@ -700,12 +701,16 @@ static const char help_printf_long[] =
         "          RMIDCORES format is 'RMID_NUMBER=CORE_LIST'\n"
         "          Example \"10=0,2,4;11=1,3,5 \"\n"
 #endif
+        "  --disable-mon-ipc\n"
+        "          Disable IPC monitoring\n"
+        "  --disable-mon-llc_miss\n"
+        "          Disable LLC misses monitoring\n"
         "  -p [EVTPIDS], --mon-pid[=EVTPIDS]\n"
         "          select top 10 most active (CPU utilizing) process ids to monitor\n"
         "          or select process ids and events to monitor.\n"
         "          EVTPIDS format is 'EVENT:PID_LIST'.\n"
         "          Examples: 'llc:22,25673' or 'all:892,4588-4592'\n"
-        "          Process' IDs can be grouped by enclosing them in square brackets,\n"
+        "          Process's IDs can be grouped by enclosing them in square brackets,\n"
         "          Examples: 'llc:[22,25673]' or 'all:892,[4588-4592]'\n"
         "          Note:\n"
         "               Requires Linux and kernel versions 4.10 and newer.\n"
@@ -747,11 +752,23 @@ static void print_help(const int is_long)
 #ifdef PQOS_RMID_CUSTOM
                m_cmd_name,
 #endif
-               m_cmd_name, m_cmd_name, m_cmd_name, m_cmd_name);
+               m_cmd_name, m_cmd_name, m_cmd_name, m_cmd_name, m_cmd_name);
         if (is_long)
                 printf("%s", help_printf_long);
 }
 
+/**
+ * @brief Displays PQoS tool version
+ */
+static void print_tool_version(void)
+{
+        int major = PQOS_VERSION / 10000;
+        int minor = (PQOS_VERSION % 10000) / 100;
+        int patch = PQOS_VERSION % 100;
+
+        printf("PQoS Tool version: %d.%d.%d\n", major, minor, patch);
+}
+
 /**
  * @brief Displays PQoS library version
  *
@@ -769,34 +786,40 @@ static void print_lib_version(const struct pqos_cap *p_cap)
 #ifdef PQOS_RMID_CUSTOM
 #define OPTION_RMID 1000
 #endif
+#define OPTION_DISABLE_MON_IPC 1001
+#define OPTION_DISABLE_MON_LLC_MISS 1002
+#define OPTION_VERSION 1003
 
 static struct option long_cmd_opts[] = {
-        {"help",            no_argument,       0, 'h'},
-        {"log-file",        required_argument, 0, 'l'},
-        {"config-file",     required_argument, 0, 'f'},
-        {"show",            no_argument,       0, 's'},
-        {"display",         no_argument,       0, 'd'},
-        {"display-verbose", no_argument,       0, 'D'},
-        {"profile-list",    no_argument,       0, 'H'},
-        {"profile-set",     required_argument, 0, 'c'},
-        {"mon-interval",    required_argument, 0, 'i'},
-        {"mon-pid",         required_argument, 0, 'p'},
-        {"mon-core",        required_argument, 0, 'm'},
-        {"mon-time",        required_argument, 0, 't'},
-        {"mon-top",         no_argument,       0, 'T'},
-        {"mon-file",        required_argument, 0, 'o'},
-        {"mon-file-type",   required_argument, 0, 'u'},
-        {"mon-reset",       no_argument,       0, 'r'},
-        {"alloc-class",     required_argument, 0, 'e'},
-        {"alloc-reset",     required_argument, 0, 'R'},
-        {"alloc-assoc",     required_argument, 0, 'a'},
-        {"verbose",         no_argument,       0, 'v'},
-        {"super-verbose",   no_argument,       0, 'V'},
-        {"iface-os",        no_argument,       0, 'I'},
-        {"percent-llc",     no_argument,       0, 'P'},
-        {"version",         no_argument,       0, 'w'},
+        {"help",                 no_argument,       0, 'h'},
+        {"log-file",             required_argument, 0, 'l'},
+        {"config-file",          required_argument, 0, 'f'},
+        {"show",                 no_argument,       0, 's'},
+        {"display",              no_argument,       0, 'd'},
+        {"display-verbose",      no_argument,       0, 'D'},
+        {"profile-list",         no_argument,       0, 'H'},
+        {"profile-set",          required_argument, 0, 'c'},
+        {"mon-interval",         required_argument, 0, 'i'},
+        {"mon-pid",              required_argument, 0, 'p'},
+        {"mon-core",             required_argument, 0, 'm'},
+        {"mon-time",             required_argument, 0, 't'},
+        {"mon-top",              no_argument,       0, 'T'},
+        {"mon-file",             required_argument, 0, 'o'},
+        {"mon-file-type",        required_argument, 0, 'u'},
+        {"mon-reset",            no_argument,       0, 'r'},
+        {"disable-mon-ipc",      no_argument,       0, OPTION_DISABLE_MON_IPC},
+        {"disable-mon-llc_miss", no_argument,       0,
+         OPTION_DISABLE_MON_LLC_MISS},
+        {"alloc-class",          required_argument, 0, 'e'},
+        {"alloc-reset",          required_argument, 0, 'R'},
+        {"alloc-assoc",          required_argument, 0, 'a'},
+        {"verbose",              no_argument,       0, 'v'},
+        {"super-verbose",        no_argument,       0, 'V'},
+        {"iface-os",             no_argument,       0, 'I'},
+        {"percent-llc",          no_argument,       0, 'P'},
+        {"version",              no_argument,       0, OPTION_VERSION},
 #ifdef PQOS_RMID_CUSTOM
-        {"rmid",            required_argument, 0, OPTION_RMID},
+        {"rmid",                 required_argument, 0, OPTION_RMID},
 #endif
         {0, 0, 0, 0} /* end */
 };
@@ -818,7 +841,7 @@ int main(int argc, char **argv)
         memset(&cfg, 0, sizeof(cfg));
 
         while ((cmd = getopt_long(argc, argv,
-                                  ":Hhwf:i:m:Tt:l:o:u:e:c:a:p:sdDrvVIPR:",
+                                  ":Hhf:i:m:Tt:l:o:u:e:c:a:p:sdDrvVIPR:",
                                   long_cmd_opts, &opt_index)) != -1) {
                 switch (cmd) {
                 case 'h':
@@ -827,7 +850,7 @@ int main(int argc, char **argv)
                 case 'H':
                         profile_l3ca_list();
                         return EXIT_SUCCESS;
-                case 'w':
+                case OPTION_VERSION:
                         selfn_print_version(NULL);
                         break;
                 case 'f':
@@ -836,10 +859,14 @@ int main(int argc, char **argv)
                                        "accepted!\n");
                                 return EXIT_FAILURE;
                         }
+                        if (optarg == NULL)
+                                return EXIT_FAILURE;
                         selfn_strdup(&sel_config_file, optarg);
                         parse_config_file(sel_config_file);
                         break;
                 case 'i':
+                        if (optarg == NULL)
+                                return EXIT_FAILURE;
                         selfn_monitor_interval(optarg);
                         break;
                 case 'p':
@@ -872,6 +899,8 @@ int main(int argc, char **argv)
                         selfn_monitor_top_like(NULL);
                         break;
                 case 'l':
+                        if (optarg == NULL)
+                                return EXIT_FAILURE;
                         selfn_log_file(optarg);
                         break;
                 case 'o':
@@ -950,6 +979,12 @@ int main(int argc, char **argv)
                 case 'I':
                         selfn_iface_os(NULL);
                         break;
+                case OPTION_DISABLE_MON_IPC:
+                        selfn_monitor_disable_ipc(NULL);
+                        break;
+                case OPTION_DISABLE_MON_LLC_MISS:
+                        selfn_monitor_disable_llc_miss(NULL);
+                        break;
 #ifdef PQOS_RMID_CUSTOM
                 case OPTION_RMID:
                         selfn_monitor_rmids(optarg);
@@ -981,8 +1016,8 @@ int main(int argc, char **argv)
         if (sel_log_file == NULL) {
                 cfg.fd_log = STDOUT_FILENO;
         } else {
-                cfg.fd_log = open(sel_log_file, O_WRONLY|O_CREAT,
-                                  FILE_READ_WRITE);
+                cfg.fd_log = safe_open(sel_log_file, O_WRONLY|O_CREAT,
+                                       FILE_READ_WRITE);
                 if (cfg.fd_log == -1) {
                         printf("Error opening %s log file!\n", sel_log_file);
                         exit_val = EXIT_FAILURE;
@@ -990,6 +1025,9 @@ int main(int argc, char **argv)
                 }
         }
 
+        if (sel_print_version)
+                print_tool_version();
+
 #ifdef PQOS_RMID_CUSTOM
         cfg.rmid_cfg = sel_rmid_cfg;
 #endif
@@ -1151,7 +1189,7 @@ int main(int argc, char **argv)
         /**
          * Close file descriptor for message log
          */
-        if (cfg.fd_log > 0 && cfg.fd_log != STDOUT_FILENO)
+        if (sel_log_file != NULL && cfg.fd_log != -1)
                 close(cfg.fd_log);
 
         /**
