@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -56,7 +56,7 @@
 #include "monitor.h"
 
 #define PQOS_MAX_PID_MON_GROUPS         256
-#define PQOS_MON_EVENT_ALL    -1
+#define PQOS_MON_EVENT_ALL    ((enum pqos_mon_event)~PQOS_MON_EVENT_TMEM_BW)
 #define PID_COL_STATUS (3) /**< col for process status letter*/
 #define PID_COL_UTIME (14) /**< col for cpu-user time in /proc/pid/stat*/
 #define PID_COL_STIME (15) /**< col for cpu-kernel time in /proc/pid/stat*/
@@ -90,6 +90,11 @@ static const char *proc_stat_whitelist = "RSD";
  */
 static int sel_monitor_num = 0;
 
+/** Trigger for disabling ipc monitoring */
+static int sel_disable_ipc = 0;
+/** Trigger for disabling llc_miss monitoring */
+static int sel_disable_llc_miss = 0;
+
 /**
  * The mask to tell which events to display
  */
@@ -174,7 +179,7 @@ struct proc_stats {
 };
 
 /**
- * Mantains single linked list implementation
+ * Maintains single linked list implementation
  */
 struct slist {
         void *data; /**< abstract data that is hold by a list element */
@@ -564,16 +569,15 @@ parse_event(char *str, enum pqos_mon_event *evt)
          * Set event value and sel_event_max which determines
          * what events to display (out of all possible)
          */
-        if (strncasecmp(str, "llc:", 4) == 0) {
+        if (strncasecmp(str, "llc:", 4) == 0)
                 *evt = PQOS_MON_EVENT_L3_OCCUP;
-                sel_events_max |= *evt;
-        } else if (strncasecmp(str, "mbr:", 4) == 0) {
+        else if (strncasecmp(str, "mbr:", 4) == 0)
                 *evt = PQOS_MON_EVENT_RMEM_BW;
-                sel_events_max |= *evt;
-        } else if (strncasecmp(str, "mbl:", 4) == 0) {
+        else if (strncasecmp(str, "mbl:", 4) == 0)
                 *evt = PQOS_MON_EVENT_LMEM_BW;
-                sel_events_max |= *evt;
-        } else if (strncasecmp(str, "all:", 4) == 0 ||
+        else if (strncasecmp(str, "mbt:", 4) == 0)
+                *evt = PQOS_MON_EVENT_TMEM_BW;
+        else if (strncasecmp(str, "all:", 4) == 0 ||
                    strncasecmp(str, ":", 1) == 0)
                 *evt = (enum pqos_mon_event) PQOS_MON_EVENT_ALL;
         else
@@ -670,6 +674,18 @@ void selfn_monitor_set_llc_percent(void)
         sel_llc_format = LLC_FORMAT_PERCENT;
 }
 
+void selfn_monitor_disable_ipc(const char *arg)
+{
+        UNUSED_ARG(arg);
+        sel_disable_ipc = 1;
+}
+
+void selfn_monitor_disable_llc_miss(const char *arg)
+{
+        UNUSED_ARG(arg);
+        sel_disable_llc_miss = 1;
+}
+
 void selfn_monitor_cores(const char *arg)
 {
         char *cp = NULL, *str = NULL;
@@ -695,14 +711,55 @@ void selfn_monitor_cores(const char *arg)
         free(cp);
 }
 
+/**
+ * Update list of events to be monitored
+ *
+ * @param [in,out] events List of monitoring events
+ * @param [in] cap_mon monitoring capability
+ */
+static void monitor_setup_events(enum pqos_mon_event *events,
+                                 const struct pqos_capability * const cap_mon)
+{
+        unsigned i;
+        enum pqos_mon_event all_evts = (enum pqos_mon_event)0;
+
+        /**
+         * get all available events on this platform
+         */
+        for (i = 0; i < cap_mon->u.mon->num_events; i++) {
+                struct pqos_monitor *mon = &cap_mon->u.mon->events[i];
+
+                all_evts |= mon->type;
+        }
+
+        /* Disable IPC monitoring */
+        if (sel_disable_ipc)
+                all_evts &= (enum pqos_mon_event)(~PQOS_PERF_EVENT_IPC);
+        /* Disable LLC miss monitoring */
+        if (sel_disable_llc_miss)
+                all_evts &= (enum pqos_mon_event)(~PQOS_PERF_EVENT_LLC_MISS);
+
+        /* check if all available events were selected */
+        if ((*events & PQOS_MON_EVENT_ALL) == PQOS_MON_EVENT_ALL) {
+                *events = (enum pqos_mon_event)(all_evts & *events);
+
+        /* Start IPC and LLC miss monitoring if available */
+        } else {
+                if (all_evts & PQOS_PERF_EVENT_IPC)
+                        *events |= (enum pqos_mon_event)PQOS_PERF_EVENT_IPC;
+                if (all_evts & PQOS_PERF_EVENT_LLC_MISS)
+                        *events |= (enum pqos_mon_event)
+                                PQOS_PERF_EVENT_LLC_MISS;
+        }
+
+        sel_events_max |= *events;
+}
+
 int monitor_setup(const struct pqos_cpuinfo *cpu_info,
                   const struct pqos_capability * const cap_mon)
 {
         unsigned i;
         int ret;
-        enum pqos_mon_event all_evts = (enum pqos_mon_event)0;
-        const enum pqos_mon_event evt_all =
-                (enum pqos_mon_event)PQOS_MON_EVENT_ALL;
 
         ASSERT(sel_monitor_num >= 0);
         ASSERT(sel_process_num >= 0);
@@ -734,35 +791,26 @@ int monitor_setup(const struct pqos_cpuinfo *cpu_info,
         } else {
                 if (strcasecmp(sel_output_type, "xml") == 0 ||
                     strcasecmp(sel_output_type, "csv") == 0)
-                        fp_monitor = fopen_check_symlink(sel_output_file, "w+");
+                        fp_monitor = safe_fopen(sel_output_file, "w+");
                 else
-                        fp_monitor = fopen_check_symlink(sel_output_file, "a");
+                        fp_monitor = safe_fopen(sel_output_file, "a");
                 if (fp_monitor == NULL) {
                         perror("Monitoring output file open error:");
                         printf("Error opening '%s' output file!\n",
                                sel_output_file);
                         return -1;
                 }
-                if (strcasecmp(sel_output_type, "xml") == 0)
-                        fprintf(fp_monitor,
-                                "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-                                "%s\n", xml_root_open);
         }
+        if (strcasecmp(sel_output_type, "xml") == 0)
+                fprintf(fp_monitor,
+                        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n%s\n",
+                        xml_root_open);
 
-        /**
-         * get all available events on this platform
-         */
-        for (i = 0; i < cap_mon->u.mon->num_events; i++) {
-                struct pqos_monitor *mon = &cap_mon->u.mon->events[i];
-
-                all_evts |= mon->type;
-        }
         /**
          * If no cores and events selected through command line
          * by default let's monitor all cores
          */
         if (sel_monitor_num == 0 && sel_process_num == 0) {
-                sel_events_max = all_evts;
                 for (i = 0; i < cpu_info->num_cores; i++) {
                         unsigned lcore  = cpu_info->cores[i].lcore;
                         uint64_t core = (uint64_t)lcore;
@@ -777,7 +825,7 @@ int monitor_setup(const struct pqos_cpuinfo *cpu_info,
                                 printf("Core group setup error!\n");
                                 exit(EXIT_FAILURE);
                         }
-                        pg->events = sel_events_max;
+                        pg->events = (enum pqos_mon_event) PQOS_MON_EVENT_ALL;
                         pg->pgrp = malloc(sizeof(*pg->pgrp));
                         if (pg->pgrp == NULL) {
                                 printf("Error with memory allocation!\n");
@@ -798,18 +846,7 @@ int monitor_setup(const struct pqos_cpuinfo *cpu_info,
                 for (i = 0; i < (unsigned)sel_monitor_num; i++) {
                         struct core_group *cg = &sel_monitor_core_tab[i];
 
-                        /* check if all available events were selected */
-                        if (cg->events == evt_all) {
-                                cg->events = all_evts;
-                                sel_events_max |= all_evts;
-                        } else {
-                                if (all_evts & PQOS_PERF_EVENT_IPC)
-                                        cg->events |= (enum pqos_mon_event)
-                                                PQOS_PERF_EVENT_IPC;
-                                if (all_evts & PQOS_PERF_EVENT_LLC_MISS)
-                                        cg->events |= (enum pqos_mon_event)
-                                                PQOS_PERF_EVENT_LLC_MISS;
-                        }
+                        monitor_setup_events(&cg->events, cap_mon);
 
                         ret = pqos_mon_start(cg->num_cores, cg->cores,
                                              cg->events, (void *)cg->desc,
@@ -846,18 +883,8 @@ int monitor_setup(const struct pqos_cpuinfo *cpu_info,
                 for (i = 0; i < (unsigned)sel_process_num; i++) {
                         struct pid_group *pg = &sel_monitor_pid_tab[i];
 
-                        /* check if all available events were selected */
-                        if (pg->events == evt_all) {
-                                pg->events = all_evts;
-                                sel_events_max |= all_evts;
-                        } else {
-                                if (all_evts & PQOS_PERF_EVENT_IPC)
-                                        pg->events |= (enum pqos_mon_event)
-                                                PQOS_PERF_EVENT_IPC;
-                                if (all_evts & PQOS_PERF_EVENT_LLC_MISS)
-                                        pg->events |= (enum pqos_mon_event)
-                                                PQOS_PERF_EVENT_LLC_MISS;
-                        }
+                        monitor_setup_events(&pg->events, cap_mon);
+
                         ret = pqos_mon_start_pids(pg->num_pids, pg->pids,
                                                   pg->events, (void *)pg->desc,
                                                   pg->pgrp);
@@ -926,6 +953,8 @@ void selfn_monitor_time(const char *arg)
 void selfn_monitor_interval(const char *arg)
 {
         sel_mon_interval = (int) strtouint64(arg);
+        if (sel_mon_interval < 1)
+                parse_error(arg, "Invalid interval value!\n");
 }
 
 void selfn_monitor_top_like(const char *arg)
@@ -1083,7 +1112,7 @@ open_proc_stat_file(const char *proc_pid_dir_name)
         snprintf(path_buf, sizeof(path_buf) - 1, proc_stat_path_fmt,
                  proc_pids_dir, proc_pid_dir_name);
 
-        return fopen(path_buf, "r");
+        return safe_fopen(path_buf, "r");
 }
 
 /**
@@ -1169,6 +1198,7 @@ get_pid_stat_val(const char *proc_pid_dir_name, const int column,
                                 return -1;
                         } else {
                                 strncpy(val, token, len_val);
+                                val[len_val - 1] = '\0';
                                 return 0;/*value can be read from *val param*/
                         }
                 }
@@ -1208,6 +1238,7 @@ get_pid_cputicks(const char *proc_pid_dir_name, uint64_t *cputicks)
         for (i = 0; i < DIM(col_val); i++) {
                 char time_str[64];
                 char *tmp;
+                unsigned long long time;
                 uint64_t time_int = 0;
                 int time_success = 0;
 
@@ -1231,7 +1262,10 @@ get_pid_cputicks(const char *proc_pid_dir_name, uint64_t *cputicks)
                                 continue;
                 }
 
-                time_int = (uint64_t)strtoull(time_str, &tmp, 10);
+                time = strtoull(time_str, &tmp, 10);
+                if (time > UINT64_MAX)
+                        return -1;
+                time_int = (uint64_t)time;
                 /* Check to make sure string converted
                  * to int correctly
                  */
@@ -1369,10 +1403,10 @@ get_pid_cores(const struct pqos_mon_data *mon_data, char *cores_s,
                 cores_s_len = strlen(cores_s);
 
                 if (i != 0 && (cores_s_len + str_len + comma_len) < len) {
-                        strcat(cores_s, ",");
-                        strcat(cores_s, core);
+                        strncat(cores_s, ",", len - cores_s_len);
+                        strncat(cores_s, core, len - cores_s_len - comma_len);
                 } else if (i == 0 && (cores_s_len + str_len) < len)
-                        strcat(cores_s, core);
+                        strncat(cores_s, core, len - cores_s_len);
                 else {
                         result = -1;
                         goto free_memory;
@@ -1958,8 +1992,12 @@ static void monitoring_ctrlc(int signo)
  * @return Number of characters added to \a data excluding NULL
  */
 static size_t
-fillin_text_column(const double val, char data[], const size_t sz_data,
-                   const int is_monitored, const int is_column_present)
+fillin_text_column(const char *format,
+                   const double val,
+                   char data[],
+                   const size_t sz_data,
+                   const int is_monitored,
+                   const int is_column_present)
 {
         static const char blank_column[] = "            ";
         size_t offset = 0;
@@ -1971,7 +2009,7 @@ fillin_text_column(const double val, char data[], const size_t sz_data,
                 /**
                  * This is monitored and we have the data
                  */
-                snprintf(data, sz_data - 1, " %11.1f", val);
+                snprintf(data, sz_data - 1, format, val);
                 offset = strlen(data);
         } else if (is_column_present) {
                 /**
@@ -1987,6 +2025,7 @@ fillin_text_column(const double val, char data[], const size_t sz_data,
 /**
  * @brief Fills in single XML column in the monitoring table
  *
+ * @param format numerical value format
  * @param val numerical value to be put into the column
  * @param data place to put formatted column into
  * @param sz_data available size for the column
@@ -1997,18 +2036,26 @@ fillin_text_column(const double val, char data[], const size_t sz_data,
  * @return Number of characters added to \a data excluding NULL
  */
 static size_t
-fillin_xml_column(const double val, char data[], const size_t sz_data,
-                  const int is_monitored, const int is_column_present,
+fillin_xml_column(const char *const format,
+                  const double val,
+                  char data[],
+                  const size_t sz_data,
+                  const int is_monitored,
+                  const int is_column_present,
                   const char node_name[])
 {
         size_t offset = 0;
 
         if (is_monitored) {
+                char formatted_val[16];
+
+                snprintf(formatted_val, 15, format, val);
+
                 /**
                  * This is monitored and we have the data
                  */
-                snprintf(data, sz_data - 1, "\t<%s>%.1f</%s>\n",
-                         node_name, val, node_name);
+                snprintf(data, sz_data - 1, "\t<%s>%s</%s>\n",
+                         node_name, formatted_val, node_name);
                 offset = strlen(data);
         } else if (is_column_present) {
                 /**
@@ -2025,6 +2072,7 @@ fillin_xml_column(const double val, char data[], const size_t sz_data,
 /**
  * @brief Fills in single CSV column in the monitoring table
  *
+ * @param format numerical value format
  * @param val numerical value to be put into the column
  * @param data place to put formatted column into
  * @param sz_data available size for the column
@@ -2034,8 +2082,12 @@ fillin_xml_column(const double val, char data[], const size_t sz_data,
  * @return Number of characters added to \a data excluding NULL
  */
 static size_t
-fillin_csv_column(const double val, char data[], const size_t sz_data,
-                  const int is_monitored, const int is_column_present)
+fillin_csv_column(const char *format,
+                  const double val,
+                  char data[],
+                  const size_t sz_data,
+                  const int is_monitored,
+                  const int is_column_present)
 {
         size_t offset = 0;
 
@@ -2043,7 +2095,7 @@ fillin_csv_column(const double val, char data[], const size_t sz_data,
                 /**
                  * This is monitored and we have the data
                  */
-                snprintf(data, sz_data - 1, ",%.1f", val);
+                snprintf(data, sz_data - 1, format, val);
                 offset = strlen(data);
         } else if (is_column_present) {
                 /**
@@ -2064,15 +2116,17 @@ fillin_csv_column(const double val, char data[], const size_t sz_data,
  * @param llc_entry LLC occupancy data structure
  * @param mbr remote memory bandwidth data
  * @param mbl local memory bandwidth data
+ * @param mbt total memory bandwidth data
  */
 static void
 print_text_row(FILE *fp,
                struct pqos_mon_data *mon_data,
                const struct llc_entry_data *llc_entry,
                const double mbr,
-               const double mbl)
+               const double mbl,
+               const double mbt)
 {
-        const size_t sz_data = 128;
+        const size_t sz_data = 256;
         char data[sz_data];
         size_t offset = 0;
         char core_list[PQOS_MAX_CORES * 4];
@@ -2083,25 +2137,55 @@ print_text_row(FILE *fp,
 
         memset(data, 0, sz_data);
 
-        offset += fillin_text_column(llc_entry->val, data + offset,
+#ifdef PQOS_RMID_CUSTOM
+        if (sel_interface == PQOS_INTER_MSR) {
+                pqos_rmid_t rmid;
+                int ret = pqos_mon_assoc_get(mon_data->cores[0], &rmid);
+
+                offset +=
+                    fillin_text_column(" %4.0f",
+                                       (double)rmid,
+                                       data + offset,
+                                       sz_data - offset,
+                                       ret == PQOS_RETVAL_OK,
+                                       sel_interface == PQOS_INTER_MSR);
+        }
+#endif
+
+        offset += fillin_text_column(" %11.2f", mon_data->values.ipc,
+                                     data + offset,
+                                     sz_data - offset,
+                                     mon_data->event & PQOS_PERF_EVENT_IPC,
+                                     sel_events_max & PQOS_PERF_EVENT_IPC);
+
+        offset += fillin_text_column(" %10.0fk", (double)
+                                     mon_data->values.llc_misses_delta/1000,
+                                     data + offset,
+                                     sz_data - offset,
+                                     mon_data->event & PQOS_PERF_EVENT_LLC_MISS,
+                                     sel_events_max & PQOS_PERF_EVENT_LLC_MISS);
+
+        offset += fillin_text_column(" %11.1f", llc_entry->val, data + offset,
                                      sz_data - offset,
                                      mon_data->event & PQOS_MON_EVENT_L3_OCCUP,
                                      sel_events_max & PQOS_MON_EVENT_L3_OCCUP);
 
-        offset += fillin_text_column(mbl, data + offset, sz_data - offset,
+        offset += fillin_text_column(" %11.1f", mbl, data + offset,
+                                     sz_data - offset,
                                      mon_data->event & PQOS_MON_EVENT_LMEM_BW,
                                      sel_events_max & PQOS_MON_EVENT_LMEM_BW);
 
-        fillin_text_column(mbr, data + offset, sz_data - offset,
-                           mon_data->event & PQOS_MON_EVENT_RMEM_BW,
-                           sel_events_max & PQOS_MON_EVENT_RMEM_BW);
+        offset += fillin_text_column(" %11.1f", mbr, data + offset,
+                                     sz_data - offset,
+                                     mon_data->event & PQOS_MON_EVENT_RMEM_BW,
+                                     sel_events_max & PQOS_MON_EVENT_RMEM_BW);
+
+        fillin_text_column(" %11.1f", mbt, data + offset, sz_data - offset,
+                           mon_data->event & PQOS_MON_EVENT_TMEM_BW,
+                           sel_events_max & PQOS_MON_EVENT_TMEM_BW);
 
         if (!process_mode())
-                fprintf(fp, "\n%8.8s %5.2f %7uk%s",
-                        (char *)mon_data->context,
-                        mon_data->values.ipc,
-                        (unsigned)mon_data->values.llc_misses_delta/1000,
-                        data);
+                fprintf(fp, "\n%8.8s%s", (char *)mon_data->context, data);
         else {
                 memset(core_list, 0, sizeof(core_list));
 
@@ -2111,11 +2195,8 @@ print_text_row(FILE *fp,
                         strncat(core_list, "err", sizeof(core_list) - 1);
                 }
 
-                fprintf(fp, "\n%8.8s %8.8s %6.2f %7uk%s",
-                        (char *)mon_data->context, core_list,
-                        mon_data->values.ipc,
-                        (unsigned)mon_data->values.llc_misses_delta/1000,
-                        data);
+                fprintf(fp, "\n%8.8s %8.8s%s", (char *)mon_data->context,
+                        core_list, data);
         }
 }
 
@@ -2128,57 +2209,99 @@ print_text_row(FILE *fp,
  * @param llc_entry LLC occupancy data structure
  * @param mbr remote memory bandwidth data
  * @param mbl local memory bandwidth data
+ * @param mbt total memory bandwidth data
  */
 static void
-print_xml_row(FILE *fp, char *time,
+print_xml_row(FILE *fp,
+              char *time,
               struct pqos_mon_data *mon_data,
               const struct llc_entry_data *llc_entry,
               const double mbr,
-              const double mbl)
+              const double mbl,
+              const double mbt)
 {
-        const size_t sz_data = 128;
+        const size_t sz_data = 256;
         char data[sz_data];
         char core_list[PQOS_MAX_CORES * 4];
         size_t offset = 0;
+        const char *l3_text = NULL;
 
         ASSERT(fp != NULL);
         ASSERT(time != NULL);
         ASSERT(mon_data != NULL);
         ASSERT(llc_entry != NULL);
 
-        const char *l3_text = (llc_entry->format == LLC_FORMAT_KILOBYTES) ?
-                "l3_occupancy_kB" : "l3_occupancy_percent";
+        switch (llc_entry->format) {
+        case LLC_FORMAT_KILOBYTES:
+                l3_text = "l3_occupancy_kB";
+                break;
+        case LLC_FORMAT_PERCENT:
+                l3_text = "l3_occupancy_percent";
+                break;
+        }
 
-        offset += fillin_xml_column(llc_entry->val, data + offset,
+#ifdef PQOS_RMID_CUSTOM
+        if (sel_interface == PQOS_INTER_MSR) {
+                pqos_rmid_t rmid;
+                int ret = pqos_mon_assoc_get(mon_data->cores[0], &rmid);
+
+                offset += fillin_xml_column("%.0f",
+                                            rmid,
+                                            data + offset,
+                                            sz_data - offset,
+                                            ret == PQOS_RETVAL_OK,
+                                            sel_interface == PQOS_INTER_MSR,
+                                            "rmid");
+        }
+#endif
+
+        offset += fillin_xml_column("%.2f", mon_data->values.ipc, data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_PERF_EVENT_IPC,
+                                    sel_events_max & PQOS_PERF_EVENT_IPC,
+                                    "ipc");
+
+        offset += fillin_xml_column("%.0f", (double)
+                                    mon_data->values.llc_misses_delta,
+                                    data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_PERF_EVENT_LLC_MISS,
+                                    sel_events_max & PQOS_PERF_EVENT_LLC_MISS,
+                                    "llc_misses");
+
+        offset += fillin_xml_column("%.1f", llc_entry->val, data + offset,
                                     sz_data - offset,
                                     mon_data->event & PQOS_MON_EVENT_L3_OCCUP,
                                     sel_events_max & PQOS_MON_EVENT_L3_OCCUP,
                                     l3_text);
 
-        offset += fillin_xml_column(mbl, data + offset, sz_data - offset,
+        offset += fillin_xml_column("%.1f", mbl, data + offset,
+                                    sz_data - offset,
                                     mon_data->event & PQOS_MON_EVENT_LMEM_BW,
                                     sel_events_max & PQOS_MON_EVENT_LMEM_BW,
                                     "mbm_local_MB");
 
-        fillin_xml_column(mbr, data + offset, sz_data - offset,
-                          mon_data->event & PQOS_MON_EVENT_RMEM_BW,
-                          sel_events_max & PQOS_MON_EVENT_RMEM_BW,
-                          "mbm_remote_MB");
+        offset += fillin_xml_column("%.1f", mbr, data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_MON_EVENT_RMEM_BW,
+                                    sel_events_max & PQOS_MON_EVENT_RMEM_BW,
+                                    "mbm_remote_MB");
+
+        fillin_xml_column("%.1f", mbt, data + offset, sz_data - offset,
+                          mon_data->event & PQOS_MON_EVENT_TMEM_BW,
+                          sel_events_max & PQOS_MON_EVENT_TMEM_BW,
+                          "mbm_total_MB");
 
         if (!process_mode())
                 fprintf(fp,
                         "%s\n"
                         "\t<time>%s</time>\n"
                         "\t<core>%s</core>\n"
-                        "\t<ipc>%.2f</ipc>\n"
-                        "\t<llc_misses>%llu</llc_misses>\n"
                         "%s"
                         "%s\n",
                         xml_child_open,
                         time,
                         (char *)mon_data->context,
-                        mon_data->values.ipc,
-                        (unsigned long long)mon_data->values.llc_misses_delta,
                         data,
                         xml_child_close);
         else {
@@ -2195,16 +2318,12 @@ print_xml_row(FILE *fp, char *time,
                         "\t<time>%s</time>\n"
                         "\t<pid>%s</pid>\n"
                         "\t<core>%s</core>\n"
-                        "\t<ipc>%.2f</ipc>\n"
-                        "\t<llc_misses>%llu</llc_misses>\n"
                         "%s"
                         "%s\n",
                         xml_child_open,
                         time,
                         (char *)mon_data->context,
                         core_list,
-                        mon_data->values.ipc,
-                        (unsigned long long)mon_data->values.llc_misses_delta,
                         data,
                         xml_child_close);
         }
@@ -2219,13 +2338,15 @@ print_xml_row(FILE *fp, char *time,
  * @param llc_entry LLC occupancy data structure
  * @param mbr remote memory bandwidth data
  * @param mbl local memory bandwidth data
+ * @param mbt total memory bandwidth data
  */
 static void
 print_csv_row(FILE *fp, char *time,
               struct pqos_mon_data *mon_data,
               const struct llc_entry_data *llc_entry,
               const double mbr,
-              const double mbl)
+              const double mbl,
+              const double mbt)
 {
         const size_t sz_data = 128;
         char data[sz_data];
@@ -2239,26 +2360,56 @@ print_csv_row(FILE *fp, char *time,
 
         memset(data, 0, sz_data);
 
-        offset += fillin_csv_column(llc_entry->val, data + offset,
+#ifdef PQOS_RMID_CUSTOM
+        if (sel_interface == PQOS_INTER_MSR) {
+                pqos_rmid_t rmid;
+                int ret = pqos_mon_assoc_get(mon_data->cores[0], &rmid);
+
+                offset += fillin_csv_column(",%.0f",
+                                            rmid,
+                                            data + offset,
+                                            sz_data - offset,
+                                            ret == PQOS_RETVAL_OK,
+                                            sel_interface == PQOS_INTER_MSR);
+        }
+#endif
+
+        offset += fillin_csv_column(",%.2f", mon_data->values.ipc,
+                                    data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_PERF_EVENT_IPC,
+                                    sel_events_max & PQOS_PERF_EVENT_IPC);
+
+        offset += fillin_csv_column(",%.0f", (double)
+                                    mon_data->values.llc_misses_delta,
+                                    data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_PERF_EVENT_LLC_MISS,
+                                    sel_events_max & PQOS_PERF_EVENT_LLC_MISS);
+
+        offset += fillin_csv_column(",%.1f", llc_entry->val, data + offset,
                                     sz_data - offset,
                                     mon_data->event & PQOS_MON_EVENT_L3_OCCUP,
                                     sel_events_max & PQOS_MON_EVENT_L3_OCCUP);
 
-        offset += fillin_csv_column(mbl, data + offset, sz_data - offset,
+        offset += fillin_csv_column(",%.1f", mbl, data + offset,
+                                    sz_data - offset,
                                     mon_data->event & PQOS_MON_EVENT_LMEM_BW,
                                     sel_events_max & PQOS_MON_EVENT_LMEM_BW);
 
-        fillin_csv_column(mbr, data + offset, sz_data - offset,
-                          mon_data->event & PQOS_MON_EVENT_RMEM_BW,
-                          sel_events_max & PQOS_MON_EVENT_RMEM_BW);
+        offset += fillin_csv_column(",%.1f", mbr, data + offset,
+                                    sz_data - offset,
+                                    mon_data->event & PQOS_MON_EVENT_RMEM_BW,
+                                    sel_events_max & PQOS_MON_EVENT_RMEM_BW);
+
+        fillin_csv_column(",%.1f", mbt, data + offset, sz_data - offset,
+                          mon_data->event & PQOS_MON_EVENT_TMEM_BW,
+                          sel_events_max & PQOS_MON_EVENT_TMEM_BW);
 
         if (!process_mode())
                 fprintf(fp,
-                        "%s,\"%s\",%.2f,%llu%s\n",
-                        time, (char *)mon_data->context,
-                        mon_data->values.ipc,
-                        (unsigned long long)mon_data->values.llc_misses_delta,
-                        data);
+                        "%s,\"%s\"%s\n",
+                        time, (char *)mon_data->context, data);
         else {
                 memset(core_list, 0, sizeof(core_list));
 
@@ -2269,11 +2420,8 @@ print_csv_row(FILE *fp, char *time,
                 }
 
                 fprintf(fp,
-                        "%s,\"%s\",%s,%.2f,%llu%s\n",
-                        time, (char *)mon_data->context, core_list,
-                        mon_data->values.ipc,
-                        (unsigned long long)mon_data->values.llc_misses_delta,
-                        data);
+                        "%s,\"%s\",\"%s\"%s\n",
+                        time, (char *)mon_data->context, core_list, data);
         }
 }
 
@@ -2301,11 +2449,20 @@ build_header_row(char *hdr, const size_t sz_hdr,
                 return;
 
         if (istext) {
-                if (!process_mode())
-                        strncpy(hdr, "    CORE   IPC   MISSES", sz_hdr - 1);
-                else
-                        strncpy(hdr, "     PID     CORE    IPC   MISSES",
-                                sz_hdr - 1);
+                if (!process_mode()) {
+                        strncpy(hdr, "    CORE", sz_hdr - 1);
+#ifdef PQOS_RMID_CUSTOM
+                        if (sel_interface == PQOS_INTER_MSR)
+                                strncat(hdr, " RMID",
+                                        sz_hdr - strlen(hdr) - 1);
+#endif
+                } else
+                        strncpy(hdr, "     PID     CORE", sz_hdr - 1);
+
+                if (sel_events_max & PQOS_PERF_EVENT_IPC)
+                        strncat(hdr, "         IPC", sz_hdr - strlen(hdr) - 1);
+                if (sel_events_max & PQOS_PERF_EVENT_LLC_MISS)
+                        strncat(hdr, "      MISSES", sz_hdr - strlen(hdr) - 1);
                 if (sel_events_max & PQOS_MON_EVENT_L3_OCCUP) {
                         if (format == LLC_FORMAT_KILOBYTES)
                                 strncat(hdr, "     LLC[KB]",
@@ -2318,15 +2475,24 @@ build_header_row(char *hdr, const size_t sz_hdr,
                         strncat(hdr, "   MBL[MB/s]", sz_hdr - strlen(hdr) - 1);
                 if (sel_events_max & PQOS_MON_EVENT_RMEM_BW)
                         strncat(hdr, "   MBR[MB/s]", sz_hdr - strlen(hdr) - 1);
+                if (sel_events_max & PQOS_MON_EVENT_TMEM_BW)
+                        strncat(hdr, "   MBT[MB/s]", sz_hdr - strlen(hdr) - 1);
         }
 
         if (iscsv) {
-                if (!process_mode())
-                        strncpy(hdr, "Time,Core,IPC,LLC Misses",
-                                sz_hdr - 1);
-                else
-                        strncpy(hdr, "Time,PID,Core,IPC,LLC Misses",
-                                sz_hdr - 1);
+                if (!process_mode()) {
+                        strncpy(hdr, "Time,Core", sz_hdr - 1);
+#ifdef PQOS_RMID_CUSTOM
+                        if (sel_interface == PQOS_INTER_MSR)
+                                strncat(hdr, ",RMID", sz_hdr - strlen(hdr) - 1);
+#endif
+                } else
+                        strncpy(hdr, "Time,PID,Core", sz_hdr - 1);
+
+                if (sel_events_max & PQOS_PERF_EVENT_IPC)
+                        strncat(hdr, ",IPC", sz_hdr - strlen(hdr) - 1);
+                if (sel_events_max & PQOS_PERF_EVENT_LLC_MISS)
+                        strncat(hdr, ",LLC Misses", sz_hdr - strlen(hdr) - 1);
                 if (sel_events_max & PQOS_MON_EVENT_L3_OCCUP) {
                         if (format == LLC_FORMAT_KILOBYTES)
                                 strncat(hdr, ",LLC[KB]",
@@ -2339,6 +2505,8 @@ build_header_row(char *hdr, const size_t sz_hdr,
                         strncat(hdr, ",MBL[MB/s]", sz_hdr - strlen(hdr) - 1);
                 if (sel_events_max & PQOS_MON_EVENT_RMEM_BW)
                         strncat(hdr, ",MBR[MB/s]", sz_hdr - strlen(hdr) - 1);
+                if (sel_events_max & PQOS_MON_EVENT_TMEM_BW)
+                        strncat(hdr, ",MBT[MB/s]", sz_hdr - strlen(hdr) - 1);
         }
 }
 
@@ -2616,16 +2784,17 @@ void monitor_loop(void)
 
                         double mbr = bytes_to_mb(pv->mbm_remote_delta) * coeff;
                         double mbl = bytes_to_mb(pv->mbm_local_delta) * coeff;
+                        double mbt = bytes_to_mb(pv->mbm_total_delta) * coeff;
 
                         if (istext)
                                 print_text_row(fp_monitor, mon_data[i],
-                                               &llc_entry, mbr, mbl);
+                                               &llc_entry, mbr, mbl, mbt);
                         if (isxml)
                                 print_xml_row(fp_monitor, cb_time, mon_data[i],
-                                              &llc_entry, mbr, mbl);
+                                              &llc_entry, mbr, mbl, mbt);
                         if (iscsv)
                                 print_csv_row(fp_monitor, cb_time, mon_data[i],
-                                              &llc_entry, mbr, mbl);
+                                              &llc_entry, mbr, mbl, mbt);
                 }
                 if (!istty && istext)
                         fputs("\n", fp_monitor);
