@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2020 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -111,6 +111,16 @@ void selfn_monitor_cores(const char *arg);
  */
 void selfn_monitor_set_llc_percent(void);
 
+/*
+ * @brief Allows to disable IPC monitoring
+ */
+void selfn_monitor_disable_ipc(const char *arg);
+
+/*
+ * @brief Allows to disable LLC misses monitoring
+ */
+void selfn_monitor_disable_llc_miss(const char *arg);
+
 /**
  * @brief Stops monitoring on selected core(s)/pid(s)
  *
