@@ -1,7 +1,7 @@
 /*
  *   BSD LICENSE
  *
- *   Copyright(c) 2016-2019 Intel Corporation. All rights reserved.
+ *   Copyright(c) 2016-2020 Intel Corporation. All rights reserved.
  *   All rights reserved.
  *
  *   Redistribution and use in source and binary forms, with or without
@@ -159,10 +159,7 @@ rdt_cfg_is_valid(const struct rdt_cfg cfg)
                         (cfg.u.l3->cdp == 0 && cfg.u.l3->u.ways_mask != 0));
 
         case PQOS_CAP_TYPE_MBA:
-                return cfg.u.mba != NULL && cfg.u.mba->mb_max > 0 &&
-                       ((cfg.u.mba->ctrl == 0 &&
-                         cfg.u.mba->mb_max <= RDT_MAX_MBA) ||
-                        cfg.u.mba->ctrl == 1);
+                return cfg.u.mba != NULL && cfg.u.mba->mb_max > 0;
 
         default:
                 break;
@@ -287,11 +284,11 @@ get_max_res_id(unsigned technology, unsigned *max_res_id)
 }
 
 /**
- * @brief Converts string \a str to UINT
+ * @brief Converts string \a str to UINT64
  *
  * @param [in] str string
  * @param [in] base numerical base
- * @param [out] value INT value
+ * @param [out] value parsed value
  *
  * @return number of parsed characters
  * @retval positive on success
@@ -302,6 +299,7 @@ str_to_uint64(const char *str, int base, uint64_t *value)
 {
         const char *str_start = str;
         char *str_end = NULL;
+        unsigned long long val;
 
         if (NULL == str || NULL == value)
                 return -EINVAL;
@@ -316,9 +314,13 @@ str_to_uint64(const char *str, int base, uint64_t *value)
                 return -EINVAL;
 
         errno = 0;
-        *value = strtoull(str_start, &str_end, base);
+        val = strtoull(str_start, &str_end, base);
         if (errno != 0 || str_end == NULL || str_end == str_start)
                 return -EINVAL;
+        if (val > UINT64_MAX)
+                return -EINVAL;
+
+        *value = val;
 
         return str_end - str;
 }
@@ -459,7 +461,7 @@ rdt_mba_str_to_rate(const char *param, struct rdt_cfg mba)
                 return -EINVAL;
 
         ret = str_to_uint64(param, 10, &rate);
-        if (ret < 0 || rate == 0 || rate > RDT_MAX_MBA)
+        if (ret < 0 || rate == 0)
                 return -EINVAL;
 
         mba.u.mba->ctrl = 0;
@@ -1296,6 +1298,9 @@ alloc_get_default_cos(struct pqos_l2ca *l2_def,
                       struct pqos_l3ca *l3_def,
                       struct pqos_mba *mba_def)
 {
+        if (m_cpu == NULL)
+                return -EINVAL;
+
         if (l2_def == NULL && l3_def == NULL && mba_def == NULL)
                 return -EINVAL;
 
@@ -1336,7 +1341,9 @@ alloc_get_default_cos(struct pqos_l2ca *l2_def,
                         mba_def->ctrl = 1;
                         mba_def->mb_max = UINT32_MAX;
                 } else
-                        mba_def->mb_max = RDT_MAX_MBA;
+                        mba_def->mb_max = (m_cpu->vendor == PQOS_VENDOR_AMD)
+                                              ? RDT_MAX_MBA_AMD
+                                              : RDT_MAX_MBA;
         }
 
         return 0;
@@ -1369,6 +1376,9 @@ cfg_configure_cos(const struct pqos_l2ca *l2ca,
         const struct pqos_coreinfo *ci = NULL;
         int ret;
 
+        if (m_cpu == NULL)
+                return -EINVAL;
+
         if (NULL == l2ca && NULL == l3ca && NULL == mba)
                 return -EINVAL;
 
@@ -1439,7 +1449,9 @@ cfg_configure_cos(const struct pqos_l2ca *l2ca,
                 if (!rdt_cfg_is_valid(wrap_mba(&mba_requested)))
                         mba_requested = mba_defs;
                 else if (mba_sc_mode(&g_cfg)) {
-                        mba_requested.mb_max = RDT_MAX_MBA;
+                        mba_requested.mb_max =
+                            (m_cpu->vendor == PQOS_VENDOR_AMD) ? RDT_MAX_MBA_AMD
+                                                               : RDT_MAX_MBA;
                         mba_requested.ctrl = 0;
                 }
 
@@ -1447,6 +1459,10 @@ cfg_configure_cos(const struct pqos_l2ca *l2ca,
                 mba_requested.class_id = cos_id;
 
                 ret = pqos_mba_set(mba_id, 1, &mba_requested, &mba_actual);
+                if (ret == PQOS_RETVAL_PARAM) {
+                        fprintf(stderr, "Invalid RDT parameters!\n");
+                        return -EINVAL;
+                }
                 if (ret != PQOS_RETVAL_OK) {
                         fprintf(stderr,
                                 "Error setting MBA COS#%u on mba id %u!\n",
@@ -1492,28 +1508,26 @@ cfg_set_cores_os(const unsigned technology,
         if (core_num == 0)
                 return -EFAULT;
 
-        if (technology & (1 << PQOS_CAP_TYPE_L2CA)) {
-                const unsigned l2_technology = 1 << PQOS_CAP_TYPE_L2CA;
-                /* Assign all cores to single COS */
-                ret = pqos_alloc_assign(l2_technology, core_array, core_num,
-                                        &cos_id);
-                switch (ret) {
-                case PQOS_RETVAL_OK:
-                        break;
-                case PQOS_RETVAL_RESOURCE:
-                        fprintf(stderr, "No free COS available!\n");
-                        return -EBUSY;
-                default:
-                        fprintf(stderr, "Unable to assign COS!\n");
-                        return -EFAULT;
-                }
+        ret = get_max_res_id(technology, &max_id);
+        if (ret != 0)
+                return ret;
 
-                ret = get_max_res_id(l2_technology, &max_id);
-                if (ret != 0)
-                        return ret;
+        /* Assign all cores to single group */
+        ret = pqos_alloc_assign(technology, core_array, core_num, &cos_id);
+        switch (ret) {
+        case PQOS_RETVAL_OK:
+                break;
+        case PQOS_RETVAL_RESOURCE:
+                fprintf(stderr, "No free COS available!\n");
+                return -EBUSY;
+        default:
+                fprintf(stderr, "Unable to assign COS L2!\n");
+                return -EFAULT;
+        }
 
-                /* Set COS definition on necessary sockets/clusters */
-                for (i = 0; i <= max_id; i++) {
+        /* Set COS definition on necessary sockets/clusters */
+        for (i = 0; i <= max_id; i++) {
+                if (technology & (1 << PQOS_CAP_TYPE_L2CA)) {
                         memset(core_array, 0, sizeof(core_array));
 
                         /* Get cores on res id i */
@@ -1530,30 +1544,7 @@ cfg_set_cores_os(const unsigned technology,
                         if (ret != 0)
                                 return ret;
                 }
-        }
-
-        if (technology & (1 << PQOS_CAP_TYPE_L3CA)) {
-                const unsigned l3_technology = 1 << PQOS_CAP_TYPE_L3CA;
-                /* Assign all cores to single COS */
-                ret = pqos_alloc_assign(l3_technology, core_array, core_num,
-                                        &cos_id);
-                switch (ret) {
-                case PQOS_RETVAL_OK:
-                        break;
-                case PQOS_RETVAL_RESOURCE:
-                        fprintf(stderr, "No free COS available!\n");
-                        return -EBUSY;
-                default:
-                        fprintf(stderr, "Unable to assign COS!\n");
-                        return -EFAULT;
-                }
-
-                ret = get_max_res_id(l3_technology, &max_id);
-                if (ret != 0)
-                        return ret;
-
-                /* Set COS definition on necessary sockets/clusters */
-                for (i = 0; i <= max_id; i++) {
+                if (technology & (1 << PQOS_CAP_TYPE_L3CA)) {
                         memset(core_array, 0, sizeof(core_array));
 
                         /* Get cores on res id i */
@@ -1571,30 +1562,7 @@ cfg_set_cores_os(const unsigned technology,
                         if (ret != 0)
                                 return ret;
                 }
-        }
-
-        if (technology & (1 << PQOS_CAP_TYPE_MBA)) {
-                const unsigned mba_technology = 1 << PQOS_CAP_TYPE_MBA;
-                /* Assign all cores to single COS */
-                ret = pqos_alloc_assign(mba_technology, core_array, core_num,
-                                        &cos_id);
-                switch (ret) {
-                case PQOS_RETVAL_OK:
-                        break;
-                case PQOS_RETVAL_RESOURCE:
-                        fprintf(stderr, "No free COS available!\n");
-                        return -EBUSY;
-                default:
-                        fprintf(stderr, "Unable to assign COS!\n");
-                        return -EFAULT;
-                }
-
-                ret = get_max_res_id(mba_technology, &max_id);
-                if (ret != 0)
-                        return ret;
-
-                /* Set COS definition on necessary sockets/clusters */
-                for (i = 0; i <= max_id; i++) {
+                if (technology & (1 << PQOS_CAP_TYPE_MBA)) {
                         memset(core_array, 0, sizeof(core_array));
 
                         /* Get cores on res id i */
@@ -1637,33 +1605,37 @@ cfg_set_cores_msr(const unsigned technology,
                   const struct pqos_l3ca *l3ca,
                   const struct pqos_mba *mba)
 {
-        int ret;
-        unsigned i, max_id;
+        int ret = PQOS_RETVAL_OK;
+        unsigned res_id, max_id;
 
         ret = get_max_res_id(technology, &max_id);
         if (ret != 0)
                 return ret;
 
         /* Assign new COS for all applicable res ids */
-        for (i = 0; i <= max_id; i++) {
-                const unsigned l2_technology = 1 << PQOS_CAP_TYPE_L2CA;
+        for (res_id = 0; res_id <= max_id; res_id++) {
                 unsigned core_array[CPU_SETSIZE] = {0};
-                unsigned core_num, cos_id;
+                unsigned core_num = 0, cos_id;
+                unsigned i;
 
                 /* Get cores on res id i */
-                if (technology & (1 << PQOS_CAP_TYPE_L2CA))
-                        ret = get_l2id_cores(cores, i, &core_num, core_array);
-                else
-                        break; /* exit this loop */
-
+                if (technology & (1 << PQOS_CAP_TYPE_L3CA)) {
+                        ret = get_l3cat_id_cores(cores, res_id, &core_num,
+                                                 core_array);
+                } else if (technology & (1 << PQOS_CAP_TYPE_MBA)) {
+                        ret = get_mba_id_cores(cores, res_id, &core_num,
+                                               core_array);
+                } else if (technology & (1 << PQOS_CAP_TYPE_L2CA)) {
+                        ret = get_l2id_cores(cores, res_id, &core_num,
+                                             core_array);
+                }
                 if (ret != 0)
                         return ret;
-
                 if (core_num == 0)
                         continue;
 
                 /* Assign COS to those cores */
-                ret = pqos_alloc_assign(l2_technology, core_array, core_num,
+                ret = pqos_alloc_assign(technology, core_array, core_num,
                                         &cos_id);
                 switch (ret) {
                 case PQOS_RETVAL_OK:
@@ -1677,88 +1649,12 @@ cfg_set_cores_msr(const unsigned technology,
                 }
 
                 /* Configure COS on res ID i */
-                ret =
-                    cfg_configure_cos(l2ca, NULL, NULL, core_array[0], cos_id);
-                if (ret != 0)
-                        return ret;
-        }
-
-        /* Assign new COS for all applicable res ids */
-        for (i = 0; i <= max_id; i++) {
-                const unsigned l3_technology = 1 << PQOS_CAP_TYPE_L3CA;
-                unsigned core_array[CPU_SETSIZE] = {0};
-                unsigned core_num, cos_id;
-
-                /* Get cores on res id i */
-                if (technology & (1 << PQOS_CAP_TYPE_L3CA))
-                        ret =
-                            get_l3cat_id_cores(cores, i, &core_num, core_array);
-                else
-                        break; /* exit this loop */
-
-                if (ret != 0)
-                        return ret;
-
-                if (core_num == 0)
-                        continue;
-
-                /* Assign COS to those cores */
-                ret = pqos_alloc_assign(l3_technology, core_array, core_num,
-                                        &cos_id);
-                switch (ret) {
-                case PQOS_RETVAL_OK:
-                        break;
-                case PQOS_RETVAL_RESOURCE:
-                        fprintf(stderr, "No free COS available!\n");
-                        return -EBUSY;
-                default:
-                        fprintf(stderr, "Unable to assign COS!\n");
-                        return -EFAULT;
+                for (i = 0; i < core_num; i++) {
+                        ret = cfg_configure_cos(l2ca, l3ca, mba, core_array[i],
+                                                cos_id);
+                        if (ret != 0)
+                                return ret;
                 }
-
-                /* Configure COS on res ID i */
-                ret =
-                    cfg_configure_cos(NULL, l3ca, NULL, core_array[0], cos_id);
-                if (ret != 0)
-                        return ret;
-        }
-
-        /* Assign new COS for all applicable res ids */
-        for (i = 0; i <= max_id; i++) {
-                const unsigned mba_technology = 1 << PQOS_CAP_TYPE_MBA;
-                unsigned core_array[CPU_SETSIZE] = {0};
-                unsigned core_num, cos_id;
-
-                /* Get cores on res id i */
-                if (technology & (1 << PQOS_CAP_TYPE_MBA))
-                        ret = get_mba_id_cores(cores, i, &core_num, core_array);
-                else
-                        break; /* exit this loop */
-
-                if (ret != 0)
-                        return ret;
-
-                if (core_num == 0)
-                        continue;
-
-                /* Assign COS to those cores */
-                ret = pqos_alloc_assign(mba_technology, core_array, core_num,
-                                        &cos_id);
-                switch (ret) {
-                case PQOS_RETVAL_OK:
-                        break;
-                case PQOS_RETVAL_RESOURCE:
-                        fprintf(stderr, "No free COS available!\n");
-                        return -EBUSY;
-                default:
-                        fprintf(stderr, "Unable to assign COS!\n");
-                        return -EFAULT;
-                }
-
-                /* Configure COS on res ID i */
-                ret = cfg_configure_cos(NULL, NULL, mba, core_array[0], cos_id);
-                if (ret != 0)
-                        return ret;
         }
 
         return 0;
