@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2020 Intel Corporation. All rights reserved.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -45,9 +45,9 @@ class TestRdtsetL3Cat(test.Test):
     ## @cond
     @pytest.fixture(autouse=True)
     def init(self, request):
-        super(TestRdtsetL3Cat, self).init(request)
+        super().init(request)
         yield
-        super(TestRdtsetL3Cat, self).fini()
+        super().fini()
     ## @endcond
 
 
