@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2019 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2020 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -64,8 +64,8 @@
 #endif
 
 #define MEMCHUNK_SIZE (PAGE_SIZE * 32 * 1024) /* 128MB chunk */
-#define CL_SIZE (64)
-#define CHUNKS (128)
+#define CL_SIZE       (64)
+#define CHUNKS        (128)
 
 #ifdef DEBUG
 #include <assert.h>
@@ -79,8 +79,8 @@
 
 #define MAX_MEM_BW 100 * 1000 /* 100GBps */
 
-#define CPU_FEATURE_SSE4_2 (1ULL << 0)
-#define CPU_FEATURE_CLWB (1ULL << 1)
+#define CPU_FEATURE_SSE4_2  (1ULL << 0)
+#define CPU_FEATURE_CLWB    (1ULL << 1)
 #define CPU_FEATURE_AVX512F (1ULL << 2)
 
 /**
@@ -446,6 +446,7 @@ cl_read_mod_write(void *p, const uint64_t v)
 }
 
 #ifdef __x86_64__
+#ifdef __AVX512F__
 /**
  * @brief WB store vector version
  *
@@ -461,6 +462,7 @@ cl_write_avx512(void *p, const uint64_t v)
                      : "r"(v), "r"(p)
                      : "%zmm1", "memory");
 }
+#endif
 
 /**
  * @brief WB vector version
@@ -539,6 +541,7 @@ cl_write(void *p, const uint64_t v)
 #endif
 }
 
+#ifdef __CLWB__
 /**
  * @brief Perform write operation to specified cache line with clwb
  *
@@ -551,6 +554,7 @@ cl_write_clwb(void *p, const uint64_t v)
         cl_write(p, v);
         cl_wb(p);
 }
+#endif
 
 /**
  * @brief Perform write operation to specified cache line with flush
@@ -612,7 +616,7 @@ cl_write_nti(void *p, const uint64_t v)
 #endif
 }
 
-#ifdef __x86_64__
+#if defined(__x86_64__) && defined(__AVX512F__)
 /**
  * @brief non-temporal store vector version
  *
@@ -630,6 +634,7 @@ cl_write_nt512(void *p, const uint64_t v)
 }
 #endif
 
+#ifdef __CLWB__
 /**
  * @brief Perform write operation to memory giving non-temporal hint with cache
  * line write back
@@ -643,6 +648,7 @@ cl_write_nti_clwb(void *p, const uint64_t v)
         cl_write_nti(p, v);
         cl_wb(p);
 }
+#endif
 
 #ifdef __x86_64__
 /**
@@ -803,27 +809,33 @@ mem_execute(const unsigned bw, const enum cl_type type)
                 case CL_TYPE_WRITE_WB:
                         cl_write(ptr, val);
                         break;
-#ifdef __x86_64__
+#if defined(__x86_64__) && defined(__AVX512F__)
                 case CL_TYPE_WRITE_WB_AVX512:
                         cl_write_avx512(ptr, val);
                         break;
 #endif
+#ifdef __CLWB__
                 case CL_TYPE_WRITE_WB_CLWB:
                         cl_write_clwb(ptr, val);
                         break;
+#endif
                 case CL_TYPE_WRITE_WB_FLUSH:
                         cl_write_flush(ptr, val);
                         break;
                 case CL_TYPE_WRITE_NTI:
                         cl_write_nti(ptr, val);
                         break;
+#ifdef __CLWB__
                 case CL_TYPE_WRITE_NTI_CLWB:
                         cl_write_nti_clwb(ptr, val);
                         break;
+#endif
 #ifdef __x86_64__
+#ifdef __AVX512F__
                 case CL_TYPE_WRITE_NT512:
                         cl_write_nt512(ptr, val);
                         break;
+#endif
                 case CL_TYPE_WRITE_NTDQ:
                         cl_write_ntdq(ptr, val);
                         break;
@@ -916,23 +928,18 @@ nano_sleep(const long interval, long usec_diff)
 {
         struct timespec req, rem;
 
-        memset(&rem, 0, sizeof(rem));
-        memset(&req, 0, sizeof(req));
         req.tv_sec = (interval - usec_diff) / 1000000L;
         req.tv_nsec = ((interval - usec_diff) % 1000000L) * 1000L;
-        if (nanosleep(&req, &rem) == -1) {
-                req = rem;
-                memset(&rem, 0, sizeof(rem));
-                nanosleep(&req, &rem);
-        }
+        if (nanosleep(&req, &rem) == -1)
+                nanosleep(&rem, NULL);
 }
 
 /**
- * @brief Converts string str to UINT
+ * @brief Converts string str to UINT64
  *
  * @param [in] str string
  * @param [in] base numerical base
- * @param [out] value UINT value
+ * @param [out] value parsed value
  *
  * @return number of parsed characters
  * @retval positive on success
@@ -1088,18 +1095,28 @@ main(int argc, char **argv)
                 break;
         case CL_TYPE_WRITE_NTI_CLWB:
         case CL_TYPE_WRITE_WB_CLWB:
+#ifdef __CLWB__
                 if (!(features & CPU_FEATURE_CLWB)) {
-                        printf("No CPU support for CLWB instruction!\n");
+                        printf("No CPU support for CLWB instructions!\n");
                         return EXIT_FAILURE;
                 }
+#else
+                printf("No compiler support for CLWB instructions!\n");
+                return EXIT_FAILURE;
+#endif
                 break;
 #ifdef __x86_64__
         case CL_TYPE_WRITE_NT512:
         case CL_TYPE_WRITE_WB_AVX512:
+#ifdef __AVX512F__
                 if (!(features & CPU_FEATURE_AVX512F)) {
                         printf("No CPU support for AVX512 instructions!\n");
                         return EXIT_FAILURE;
                 }
+#else
+                printf("No compiler support for AVX512 instructions!\n");
+                return EXIT_FAILURE;
+#endif
                 break;
 #endif
         default:
